%This makes the following figures/analysis using ALL of the available data
%
% 1. LOESS (two-class and 5-class)
% 2. ROC
% 3. Differences by individual question
% 4. Binomial Regression

% fprintf('WARNING: This is destructive of variables for Prospective\n');
% fprintf(' and Retrospective analyzed separately\n');

RoS_LoadRetrospective;
RoS_LoadProspective;
% close all

dirs.asigqs=[dirs.home 'RetroSigQsa.csv'];
dirs.table1=[dirs.home 'Table1.csv'];
dirs.Stable1=[dirs.home 'SupplTable1.csv'];
dirs.Stable1B=[dirs.home 'SupplTable1B.csv'];
dirs.Stable2=[dirs.home 'SupplTable2.csv'];
data.all =[data.retro;data.prosp];
data.asum=[data.retrosum;data.prospsum];
ifix=find(data.asum(:,2)==0);
data.asum(ifix,2)=n.RoSColp;
data.aperc=[data.perc;data.percp];
data.aclass=[data.class;data.classp];
data.ademo=[data.demo;data.demop];
ix.aShortRoS=find(data.asum(:,2)==n.RoSSho);

%% Summary Statistics
n.aclass=length(unique(data.aclass));
summary.aclasses=zeros(n.aclass+1,5);
% 1: Class value
% 2: n
% 3: Average Positive
% 4: Std Positive/sqrt(n)
% 5: % above 17%
summary.aclasses(1:n.aclass,1)=unique(data.aclass);
summary.aclasses(n.aclass+1,1)=411; % all

ix.aclassid=cell(n.aclass+1,1);
for ind=1:n.aclass+1
    if ind>n.aclass
        ix.aclassid{ind}=ix.aclassid{1};
        for jnd=2:n.aclass
            ix.aclassid{ind}=union(ix.aclassid{ind},ix.aclassid{jnd});
        end
    else
        ix.aclassid{ind}=find(data.aclass==summary.aclasses(ind,1));
    end
    summary.aclasses(ind,2)=length(ix.aclassid{ind});
    summary.aclasses(ind,3)=mean(data.asum(ix.aclassid{ind},1));
    summary.aclasses(ind,4)=std( data.asum(ix.aclassid{ind},1))/sqrt(summary.aclasses(ind,2));
    summary.aclasses(ind,5)=sum(data.aperc(ix.aclassid{ind})>0.17)/summary.aclasses(ind,2);
end

%% Percent-Based Analysis
% Set up variables
ix.aDxPNES=find(summary.aclasses(1:n.class,1)==-2);
ix.aDxES  =find(summary.aclasses(1:n.class,1)>0); 
n.aPNESSho=n.PNESSho+n.pPNESSho;
n.aESSho  =n.ESSho  +n.pESSho;
ix.ahasdx=union(ix.aclassid{ix.aDxPNES},ix.aclassid{ix.aDxES});

%% Write out for Binomial Regression in R
dirs.binregR=[dirs.home 'RoS_All_BinReg.csv'];
fid=fopen(dirs.binregR,'w');
fprintf(fid,'NPos,NNeg,Dx,Sex,Comorb\n');
clear tmp;
for snd=1:size(data.asum,1)
    tmp.ix=snd;
    fprintf(fid,[num2str(data.asum(tmp.ix,1)) ',' num2str(data.asum(tmp.ix,2)-data.asum(tmp.ix,1)) ',' num2str(data.aclass(tmp.ix)) ',' num2str(data.ademo(tmp.ix,1)) ',' num2str(data.ademo(tmp.ix,3)) '\n']);
end
fclose(fid);

%% ROC curve
n.adataanddx=length(ix.aclassid{ix.aDxPNES})+length(ix.aclassid{ix.aDxES});
thresh.aperc=unique(data.percp);
n.perc.athresh=length(thresh.aperc);
data.aROC=zeros(n.perc.athresh,2);
data.aAUC=0;
% 1: TPR (sens for PNES)
% 2: FPR (1-spec for ES)
for tnd=1:n.perc.athresh
    data.aROC(tnd,1)=sum(data.aperc(ix.aclassid{ix.aDxPNES})>=thresh.aperc(tnd))/summary.aclasses(ix.aDxPNES,2);
    data.aROC(tnd,2)=sum(data.aperc(ix.aclassid{ix.aDxES})>thresh.aperc(tnd))/summary.aclasses(ix.aDxES,2);
    if tnd>1
        data.aAUC=data.aAUC+(1-data.aROC(tnd,2))*(data.aROC(tnd-1,1)-data.aROC(tnd,1));
    end
end
perc.abacc=(data.aROC(:,1)+(1-data.aROC(:,2)))/2;
[perc.amaxbacc,tmp]=max(perc.abacc);
perc.amaxbath=thresh.aperc(tmp);
perc.amaxbasens=data.aROC(tmp,1);
perc.amaxbaspec=data.aROC(tmp,2);
perc.aacc =(data.aROC(:,1)*summary.aclasses(ix.aDxPNES,2)+(1-data.aROC(:,2))*summary.aclasses(ix.aDxES,2))/(summary.aclasses(ix.aDxPNES,2)+summary.aclasses(ix.aDxES,2));
[perc.amaxacc,tmp] =max(perc.aacc);
perc.aaccp=(1-binocdf(perc.amaxacc*n.adataanddx,n.adataanddx,max(summary.aclasses([ix.aDxPNES,ix.aDxES],2))/n.adataanddx))*2;
perc.amaxacth=thresh.aperc(tmp);
perc.amaxasen=data.aROC(tmp,1);
perc.amaxaspe=data.aROC(tmp,2);
perc.aAUC    =data.aAUC;
figure
pl1=plot(data.aROC(:,2),data.aROC(:,1),'color','black','LineWidth',2);
title('All Data')
xlabel('Percent ES above threshold (false positive rate)');
ylabel('Percent PNES above threshold (true positive rate)');
set(gca,'xlim',[0 1],'ylim',[0 1]);
set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
axis square

%% Descriptive Trend Figure - PNES vs ES
figure;
ssigma=0.015; % Gaussian window

% make exact figure
tmps.percvals=unique(data.aperc);
tmps.perchist=zeros(length(tmps.percvals),2);
for ind=1:length(tmps.percvals)
    tmps.perchist(ind,1)=sum(data.aperc(ix.aclassid{ix.aDxPNES})==tmps.percvals(ind));
    tmps.perchist(ind,2)=sum(data.aperc(ix.aclassid{ix.aDxES})==tmps.percvals(ind));
end
% add smoothing
perc.val=0:1/size(data.prosp,2):1;
n.percvals=length(perc.val);
perc.aloess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
% Gaussian smoothing kernel applied onto tmps.perchist
for ind=1:n.percvals
    for jnd=1:length(tmps.percvals)
        perc.aloess(ind,1)=perc.aloess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
        perc.aloess(ind,2)=perc.aloess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
        perc.aloess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
    end
end
perc.aloess=perc.aloess./repmat(perc.aloess(:,3),[1 3]);
perc.afreqbars=zeros(n.percvals,3);
perc.afreqbars(:,2)=perc.aloess(:,1)./perc.aloess(:,2);
for ind=1:n.percvals
    if perc.afreqbars(ind,2)==1
        perc.afreqbars(ind,[1 3])=abs(perc.afreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.aloess(ind,2)),1-1/2/floor(perc.aloess(ind,2)))/floor(perc.aloess(ind,2)));
    else
        perc.afreqbars(ind,[1 3])=abs(perc.afreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.aloess(ind,2)),perc.afreqbars(ind,2))/floor(perc.aloess(ind,2)));
    end
    if perc.aloess(ind,2)<2
        perc.afreqbars(ind,:)=NaN;
    end
end
hold on
pl4=plot(perc.val,perc.aloess(:,1)./perc.aloess(:,2),'Color',[0 0 0],'LineWidth',2);
ebs=errbar(perc.val,perc.afreqbars(:,2),perc.afreqbars(:,1),perc.afreqbars(:,3),'LineWidth',3,'Color',[0 0 0]);
hold off
% removeErrorBarEnds(ebs);

title('All Data');
ylabel('Percent Patients with PNES vs ES');
xlabel('Percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[0 0.4],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

%>= figure
tmpsGT.apercvals=unique(data.aperc);
tmpsGT.aperchist=zeros(n.percvals,2);
perc.afreqbarsGT=zeros(n.percvals,3);
for ind=1:n.percvals
    tmpsGT.aperchist(ind,1)=sum(data.aperc(ix.aclassid{ix.aDxPNES})>=perc.val(ind));
    tmpsGT.aperchist(ind,2)=sum(data.aperc(ix.aclassid{ix.aDxES})>=perc.val(ind));
    tmps.n=sum(tmpsGT.aperchist(ind,:));
    perc.afreqbarsGT(ind,2)=tmpsGT.aperchist(ind,1)/tmps.n;
    if perc.afreqbarsGT(ind,2)==1
        perc.afreqbarsGT(ind,[1 3])=abs(perc.afreqbarsGT(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(tmps.n),1-1/2/floor(tmps.n))/floor(tmps.n));
    else
        perc.afreqbarsGT(ind,[1 3])=abs(perc.afreqbarsGT(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(tmps.n),perc.afreqbarsGT(ind,2))/floor(tmps.n));
    end
    if tmps.n<=2
        perc.afreqbars(ind,:)=NaN;
    end
end

figure;
hold on
pl4=plot(perc.val,perc.afreqbarsGT(:,2),'Color',[0 0 0],'LineWidth',2);
ebs=errbar(perc.val,perc.afreqbarsGT(:,2),perc.afreqbarsGT(:,1),perc.afreqbarsGT(:,3),'LineWidth',3,'Color',[0 0 0]);
hold off

ylabel('Percent Patients with PNES vs ES');
xlabel('Greater than or equal to percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[0 0.4],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

%% Descriptive Trend Figure - 5 classes
figure;
ssigma=0.015; % Gaussian window

% make exact figure
tmps5.percvals=unique(data.aperc);
tmps5.perchist=zeros(length(tmps.percvals),n.class);
for ind=1:length(tmps5.percvals)
    for cnd=1:n.class
        tmps5.perchist(ind,cnd)=sum(data.aperc(ix.aclassid{cnd})==tmps5.percvals(ind));
    end
end
% add smoothing
perc.val=0:1/size(data.prosp,2):1;
n.percvals=length(perc.val);
perc.a5loess=zeros(n.percvals,3,n.class); %1: freq, 2:n, 3:for norming
% Gaussian smoothing kernel applied onto tmps5.perchist
for ind=1:n.percvals
    for jnd=1:length(tmps5.percvals)
        for cnd=1:n.class
            perc.a5loess(ind,1,cnd)=perc.a5loess(ind,1,cnd)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*tmps5.perchist(jnd,cnd);
        end
        perc.a5loess(ind,2,1)=perc.a5loess(ind,2,1)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*sum(tmps5.perchist(jnd,:),2);
        perc.a5loess(ind,3,1)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
    end
end
perc.a5loess=perc.a5loess./repmat(perc.a5loess(:,3,1),[1 3 n.class]);
perc.a5freqbars=zeros(n.percvals,n.class); % Note that we don't have error bars because that would be too messy
perc.a5freqbars=squeeze(perc.a5loess(:,1,:))./repmat(perc.a5loess(:,2,1),[1 n.class]);
for ind=1:n.percvals
    if perc.a5loess(ind,2,1)<2
        perc.a5freqbars(ind,:)=NaN;
    end
end
ordcl=[2 1 4 3 5];
bar5=bar(perc.val,perc.a5freqbars(:,ordcl),'stacked','BarWidth',1);
title('All Data');
set(gca,'fontsize',16);
ylabel('Percent of All Patients');
xlabel('Percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[-0.01 0.4],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

set(bar5(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName','PNES');
set(bar5(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName','Mixed');
set(bar5(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName','Inconclusive');
set(bar5(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName','Physio NES');
set(bar5(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName','ES');
legend1 = legend(gca,'show');

%>=

tmpsGT5.apercvals=unique(data.aperc);
tmpsGT5.aperchist=zeros(n.percvals,n.class);
perc.afreqbarsGT5=zeros(n.percvals,n.class);
for ind=1:n.percvals
    for cnd=1:n.class
        tmpsGT5.aperchist(ind,cnd)=sum(data.aperc(ix.aclassid{cnd})>=perc.val(ind));
    end
    tmps.n=sum(tmpsGT5.aperchist(ind,:));
    for cnd=1:n.class
        perc.afreqbarsGT5(ind,cnd)=tmpsGT5.aperchist(ind,cnd)/tmps.n;
    end
end
figure
ordcl=[2 1 4 3 5];
bar5=bar(perc.val,perc.afreqbarsGT5(:,ordcl),'stacked','BarWidth',1);
title('All Data');
set(gca,'fontsize',16);
ylabel('Percent of All Patients');
xlabel('Greater than or equal to percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[-0.01 0.4],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

set(bar5(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName','PNES');
set(bar5(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName','Mixed');
set(bar5(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName','Inconclusive');
set(bar5(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName','Physio NES');
set(bar5(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName','ES');
legend1 = legend(gca,'show');

%% Descriptive Statistics by Individual Question
summary.aindiv=zeros(n.class+1,size(data.all,2),2);
% Mean
% SE
% p-ESvsClass, or if ES, then PNESvsES using only PNES & ES data
for jnd=1:size(data.all,2)
    if isempty(intersect(ix.shortmissing,jnd+5)) % is the question on the short RoS form
        for ind=1:n.class+1
            summary.aindiv(ind,jnd,1)=mean(data.all(ix.aclassid{ind},jnd));
            summary.aindiv(ind,jnd,2)=std(data.all(ix.aclassid{ind},jnd))/sqrt(length(ix.aclassid{ind}));
        end
        %PNES vs ES
        tmpn=length(ix.aclassid{ix.aDxPNES})+length(ix.aclassid{ix.aDxES});
        modeldata.Yi=[data.all(ix.aclassid{ix.aDxPNES},jnd);data.all(ix.aclassid{ix.aDxES},jnd)];
        modeldata.Xi=zeros(tmpn,3);
        modeldata.Xi(:,1)=[ones(length(ix.aclassid{ix.aDxPNES}),1);zeros(length(ix.aclassid{ix.aDxES}),1)];
        modeldata.Xi(:,2)=[data.ademo(ix.aclassid{ix.aDxPNES},1);data.ademo(ix.aclassid{ix.aDxES},1)];
        modeldata.Xi(:,3)=[data.ademo(ix.aclassid{ix.aDxPNES},3);data.ademo(ix.aclassid{ix.aDxES},3)];
        %5-class
        tmpn5=length(ix.aclassid{n.class+1});
        modeldata.Yi5=data.all(ix.aclassid{n.class+1},jnd);
        modeldata.Xi5=zeros(tmpn5,6);
        cnt=0;
        for ind=setdiff(1:5,ix.aDxES)
            cnt=cnt+1;
            modeldata.Xi5(ix.aclassid{ind},cnt)=1;
        end
        modeldata.Xi5(:,5)=data.ademo(ix.aclassid{n.class+1},1);
        modeldata.Xi5(:,6)=data.ademo(ix.aclassid{n.class+1},3);
    else % question is off the short RoS
        fprintf([heads{jnd+5}{1} '\n']);
        ix.aLongRoS=setdiff(ix.aclassid{n.class+1},ix.aShortRoS);
        for ind=1:n.class+1
            summary.aindiv(ind,jnd,1)=mean(data.all(intersect(ix.aclassid{ind},ix.aLongRoS),jnd));
            summary.aindiv(ind,jnd,2)=std(data.all(intersect(ix.aclassid{ind},ix.aLongRoS),jnd))/sqrt(length(intersect(ix.aclassid{ind},ix.aLongRoS)));
        end
        %PNES vs ES
        tmpn=length(intersect(ix.aclassid{ix.aDxPNES},ix.aLongRoS))+length(intersect(ix.aclassid{ix.aDxES},ix.aLongRoS));
        modeldata.Yi=[data.all(intersect(ix.aclassid{ix.aDxPNES},ix.aLongRoS),jnd);data.all(intersect(ix.aclassid{ix.aDxES},ix.aLongRoS),jnd)];
        modeldata.Xi=zeros(tmpn,3);
        modeldata.Xi(:,1)=[ones(length(intersect(ix.aclassid{ix.aDxPNES},ix.aLongRoS)),1);zeros(length(intersect(ix.aclassid{ix.aDxES},ix.aLongRoS)),1)];
        modeldata.Xi(:,2)=[data.ademo(intersect(ix.aclassid{ix.aDxPNES},ix.aLongRoS),1);data.ademo(intersect(ix.aclassid{ix.aDxES},ix.aLongRoS),1)];
        modeldata.Xi(:,3)=[data.ademo(intersect(ix.aclassid{ix.aDxPNES},ix.aLongRoS),3);data.ademo(intersect(ix.aclassid{ix.aDxES},ix.aLongRoS),3)];
        %5-class
        tmpn5=length(ix.aclassid{n.class+1});
        modeldata.Yi5=data.all(ix.aclassid{n.class+1},jnd);
        modeldata.Xi5=zeros(tmpn5,6);
        cnt=0;
        for ind=setdiff(1:5,ix.aDxES)
            cnt=cnt+1;
            modeldata.Xi5(ix.aclassid{ind},cnt)=1;
        end
        modeldata.Xi5(:,5)=data.ademo(ix.aclassid{n.class+1},1);
        modeldata.Xi5(:,6)=data.ademo(ix.aclassid{n.class+1},3);
        modeldata.Yi5=modeldata.Yi5(ix.aLongRoS);
        modeldata.Xi5=modeldata.Xi5(ix.aLongRoS,:);
    end
    
    % NOTE THAT NEED TO DO WITH OTHER CLASSES TO FIGURE OUT SIGNIFICANT
    % PATTERNS
    warning off
    [bi,devi,statsi]=glmfit(modeldata.Xi,modeldata.Yi,'binomial');
    [bi5,devi5,statsi5]=glmfit(modeldata.Xi5,modeldata.Yi5,'binomial');
    warning o
    summary.aindiv(5,jnd,3)=statsi.p(2);
    summary.aindiv(1:4,jnd,3)=statsi5.p(2:5);
end
[asortedsig ix.asigsort]=sort(summary.aindiv(ix.aDxPNES,:,3));
minsiga=0;
for jnd=1:length(asortedsig)
    asortedsig(jnd)=asortedsig(jnd)*length(asortedsig)/jnd;
    if asortedsig(jnd)<0.05
        if minsiga==0
            minsiga=jnd;
        else
            if jnd==minsiga+1
                minsiga=jnd;
%             else
                % there was a non-significant one before this
            end
        end
    end
end

%Make Supplemental Tables
fid=fopen(dirs.Stable2,'w');
fprintf(fid,'Question,ES,PSLE,Inconclusive,Mixed,PNES,p(PNES=ES)\n');
for ind=1:78
    fprintf(fid,[heads{ix.Colmin-2+ind}{:} ',' num2str(summary.aindiv(5,ind,1)) ',']);
    fprintf(fid,[num2str(summary.aindiv(3,ind,1)) ',' num2str(summary.aindiv(4,ind,1)) ',']);
    fprintf(fid,[num2str(summary.aindiv(1,ind,1)) ',' num2str(summary.aindiv(2,ind,1)) ',']);
    fprintf(fid,[num2str(summary.aindiv(1,ind,3)) '\n']);
end
fclose(fid);

fid=fopen(dirs.Stable1B,'w');
fprintf(fid,'Question,Dataset,ES,PSLE,Inconclusive,Mixed,PNES,p(PNES=ES)\n');
for ind=1:78
    fprintf(fid,[heads{ix.Colmin-2+ind}{:} ',Retro,' num2str(summary.indiv(5,ind,1)) ',']);
    fprintf(fid,[num2str(summary.indiv(3,ind,1)) ',' num2str(summary.indiv(4,ind,1)) ',']);
    fprintf(fid,[num2str(summary.indiv(1,ind,1)) ',' num2str(summary.indiv(2,ind,1)) ',']);
    fprintf(fid,[num2str(summary.indiv(1,ind,3)) '\n']);
    fprintf(fid,[',Prosp,' num2str(summary.pindiv(5,ind,1)) ',']);
    fprintf(fid,[num2str(summary.pindiv(3,ind,1)) ',' num2str(summary.pindiv(4,ind,1)) ',']);
    fprintf(fid,[num2str(summary.pindiv(1,ind,1)) ',' num2str(summary.pindiv(2,ind,1)) ',']);
    fprintf(fid,[num2str(summary.pindiv(1,ind,3)) '\n']);
end
fclose(fid);


%% Add FDR Correction!
ix.asigfac=ix.asigsort(1:minsiga);

% Write Out Table of Significant Factors
fidd=fopen(dirs.asigqs,'w');
fprintf(fidd,'Question,Mixed,Inconclusive,Physio,PNES,ES,p\n');
ix.classord=[1 4 3 2 5];
for ind=ix.asigfac
    fprintf(fidd,heads{ind+6}{1});
    for jnd=1:n.class
        if max(ix.classord)==n.aclass
            fprintf(fidd,[',' num2str(round(100*summary.aindiv(ix.classord(jnd),ind,1))) ' (' num2str(round(100*summary.aindiv(ix.classord(jnd),ind,2))) ')']);
        else
            error 'Fix the class order'
        end
    end
    fprintf(fidd,[',' num2str(summary.aindiv(1,ind,3)) '\n']);
end
fclose(fidd);

% display RoS response rates
figure
n.maxdisplay=minsiga;
ord=[2 1 4 3 5];
% plot2=barh(summary.aindiv([ix.aDxPNES ix.aDxES],ix.asigfac(n.maxdisplay:-1:1),1)','BarWidth',1);
plot2=barh(summary.aindiv(ord,ix.asigfac(n.maxdisplay:-1:1),1)','BarWidth',1);
hold on
pos=[-0.31,-0.155,0,0.155,0.31];
cnti=1;
for ind=ord
    cntj=1;
    for jnd=ix.asigfac(n.maxdisplay:-1:1)
        ebs3=errbar(summary.aindiv(ind,jnd,1),cntj+pos(cnti),summary.aindiv(ind,jnd,2),'horiz','LineWidth',1,'Color',[0 0 0]);
        cntj=cntj+1;
    end
    cnti=cnti+1;
end
hold off
labs=cell(n.maxdisplay,1);
for ind=1:n.maxdisplay
    labs{ind}=[num2str(n.maxdisplay-ind+1) ':' heads{6+ix.asigfac(n.maxdisplay+1-ind)}{:}];
end
set(gca,'ylim',[0.5 n.maxdisplay+0.5],'ytick',1:n.maxdisplay,'yticklabel',labs);
xlabel('Rate of Positive Response');
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(plot2(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','Mixed PNES+ES');
set(plot2(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','PNES');
set(plot2(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','PSLE');
set(plot2(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','Inconclusive');
set(plot2(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','ES');
legend1 = legend(gca,'show');

figure
n.maxdisplay=10;
% plot2=barh(summary.aindiv([ix.aDxPNES ix.aDxES],ix.asigfac(n.maxdisplay:-1:1),1)','BarWidth',1);
plot2=barh(summary.aindiv(ord,ix.asigfac(n.maxdisplay:-1:1),1)','BarWidth',1);
hold on
pos=[-0.31,-0.155,0,0.155,0.31];
cnti=1;
for ind=ord
    cntj=1;
    for jnd=ix.asigfac(n.maxdisplay:-1:1)
        ebs3=errbar(summary.aindiv(ind,jnd,1),cntj+pos(cnti),summary.aindiv(ind,jnd,2),'horiz','LineWidth',1.5,'Color',[0 0 0]);
        cntj=cntj+1;
    end
    cnti=cnti+1;
end
hold off
labs=cell(n.maxdisplay,1);
for ind=1:n.maxdisplay
    labs{ind}=[num2str(n.maxdisplay-ind+1) ':' heads{6+ix.asigfac(n.maxdisplay+1-ind)}{:}];
end
set(gca,'fontsize',16);
set(gca,'ylim',[0.5 n.maxdisplay+0.5],'ytick',1:n.maxdisplay,'yticklabel',labs);
xlabel('Rate of Positive Response');
set(gca,'xlim',[0 0.7],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(plot2(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','Mixed PNES+ES');
set(plot2(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','PNES');
set(plot2(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','PSLE');
set(plot2(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','Inconclusive');
set(plot2(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),... %'FaceColor',[0.70 0.3 1],...
    'DisplayName','ES');
legend1 = legend(gca,'show');

%% Performance Statistics
% Robles 17% on ALL Data
robles.twobytwo=zeros(2,2);
robles.twobytwo(2,2)=summary.aclasses(2,5)*summary.aclasses(2,2);
robles.twobytwo(2,1)=(1-summary.aclasses(2,5))*summary.aclasses(2,2);
robles.twobytwo(1,2)=summary.aclasses(5,5)*summary.aclasses(5,2);
robles.twobytwo(1,1)=(1-summary.aclasses(5,5))*summary.aclasses(5,2);
summary.perf(1,1,3)=sum(diag(robles.twobytwo))/sum(sum(robles.twobytwo));
summary.perf(1,2,3)=binoinv(0.025,sum(sum(robles.twobytwo)),summary.perf(1,1,3))/sum(sum(robles.twobytwo));
summary.perf(1,3,3)=binoinv(0.975,sum(sum(robles.twobytwo)),summary.perf(1,1,3))/sum(sum(robles.twobytwo));
summary.perf(2,1,3)=robles.twobytwo(1,1)/sum(robles.twobytwo(1,:));
summary.perf(2,2,3)=binoinv(0.025,sum(robles.twobytwo(1,:)),summary.perf(2,1,3))/sum(robles.twobytwo(1,:));
summary.perf(2,3,3)=binoinv(0.975,sum(robles.twobytwo(1,:)),summary.perf(2,1,3))/sum(robles.twobytwo(1,:));
summary.perf(3,1,3)=robles.twobytwo(2,2)/sum(robles.twobytwo(2,:));
summary.perf(3,2,3)=binoinv(0.025,sum(robles.twobytwo(2,:)),summary.perf(3,1,3))/sum(robles.twobytwo(2,:));
summary.perf(3,3,3)=binoinv(0.975,sum(robles.twobytwo(2,:)),summary.perf(3,1,3))/sum(robles.twobytwo(2,:));
summary.perf(4,1,3)=robles.twobytwo(1,1)/sum(robles.twobytwo(:,1));
summary.perf(4,2,3)=binoinv(0.025,sum(robles.twobytwo(:,1)),summary.perf(4,1,3))/sum(robles.twobytwo(:,1));
summary.perf(4,3,3)=binoinv(0.975,sum(robles.twobytwo(:,1)),summary.perf(4,1,3))/sum(robles.twobytwo(:,1));
summary.perf(5,1,3)=robles.twobytwo(2,2)/sum(robles.twobytwo(:,2));
summary.perf(5,2,3)=binoinv(0.025,sum(robles.twobytwo(:,2)),summary.perf(5,1,3))/sum(robles.twobytwo(:,2));
summary.perf(5,3,3)=binoinv(0.975,sum(robles.twobytwo(:,2)),summary.perf(5,1,3))/sum(robles.twobytwo(:,2));

chance.perf=zeros(5,3);
chance.perf(1,1)=summary.classesp(5,2)/(summary.classesp(5,2)+summary.classesp(2,2));
chance.perf(1,2)=chance.perf(1,1);
chance.perf(1,3)=summary.aclasses(5,2)/(summary.aclasses(5,2)+summary.aclasses(2,2));
chance.perf(2:5,:)=0.5;

%Figure 3: Performance
% Add other predictive methods (Robles, Balanced Acc)
figure
bar3=barh(squeeze(summary.perf(5:-1:1,1,[1 3])),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
set(gca,'fontsize',16);
set(bar3(1),'FaceColor',[0.70 0.3 1],...
    'DisplayName','RoS+Sex+Comorbid');
set(bar3(2),'FaceColor',[0.3 0.8 1],...
    'DisplayName','Robles');
legend1 = legend(gca,'show');
hold on
% bar4=barh(chance.perf(5:-1:1,[1 3]),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
% pos=[-0.23,0,.23];
pos=[-0.14,0,0.14];
for jnd=[1 3]
    ebs3=errbar(summary.perf(5:-1:1,1,jnd),(1:5)+pos(jnd),abs(summary.perf(5:-1:1,1,jnd)-summary.perf(5:-1:1,2,jnd)),abs(summary.perf(5:-1:1,1,jnd)-summary.perf(5:-1:1,3,jnd)),'horiz','LineWidth',3,'Color',[0 0 0]);
end
cha3=barh(chance.perf(5:-1:1,[1 3]),'BarWidth',1,'FaceColor',[0.8 0.8 0.8],'EdgeColor',[1 1 1]);
hold off
set(gca,'ytick',1:5,'yticklabel',{'PNES-PV','ES-PV','Specificity','Sensitivity','Accuracy'});
set(gca,'xlim',[0 1],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});

%% Table 1
summary.table1=zeros(n.class+1,8);
% Each class + All
% 1: Count
% 2: Age Min
% 3: Age 95% CI LB
% 4: Age 95% CI UB
% 5: Age Max
% 6: % Female
% 7: #Comorb 95% CI LB
% 8: #Comorb 95% CI UB
cnt=0;
%Count
summary.table1(1:n.class+1,1)=summary.aclasses([ord n.class+1],2);
for Dx=ord;
    cnt=cnt+1;
    %Age
    summary.table1(cnt,2)=min(data.ademo(ix.aclassid{Dx},2));
    summary.table1(cnt,3)=mean(data.ademo(ix.aclassid{Dx},2))-1.96*std(data.ademo(ix.aclassid{Dx},2))/sqrt(length(ix.aclassid{Dx}));
    summary.table1(cnt,4)=mean(data.ademo(ix.aclassid{Dx},2))+1.96*std(data.ademo(ix.aclassid{Dx},2))/sqrt(length(ix.aclassid{Dx}));
    summary.table1(cnt,5)=max(data.ademo(ix.aclassid{Dx},2));
    %Sex
    summary.table1(cnt,6)=mean(data.ademo(ix.aclassid{Dx},1));
    %Comorb
    summary.table1(cnt,7)=mean(data.ademo(ix.aclassid{Dx},3))-1.96*std(data.ademo(ix.aclassid{Dx},3))/sqrt(length(ix.aclassid{Dx}));
    summary.table1(cnt,8)=mean(data.ademo(ix.aclassid{Dx},3))+1.96*std(data.ademo(ix.aclassid{Dx},3))/sqrt(length(ix.aclassid{Dx}));
end
summary.table1(n.class+1,2)=min(data.ademo(:,2));
summary.table1(n.class+1,3)=mean(data.ademo(:,2))-1.96*std(data.ademo(:,2))/sqrt(summary.table1(n.class+1,1));
summary.table1(n.class+1,4)=mean(data.ademo(:,2))+1.96*std(data.ademo(:,2))/sqrt(summary.table1(n.class+1,1));
summary.table1(n.class+1,5)=max(data.ademo(:,2));
%Sex
summary.table1(n.class+1,6)=mean(data.ademo(:,1));
%Comorb
summary.table1(n.class+1,7)=mean(data.ademo(:,3))-1.96*std(data.ademo(:,3))/sqrt(summary.table1(n.class+1,1));
summary.table1(n.class+1,8)=mean(data.ademo(:,3))+1.96*std(data.ademo(:,3))/sqrt(summary.table1(n.class+1,1));


fid=fopen(dirs.table1,'w');
fprintf(fid,'Diagnosis,Count,Age min (95 CI) max,Female,#Comorbid (95 CI) \n');
Dxord={'PNES','Mixed PNES+ES','Inconclusive','Physiologic','ES','All Patients'};
for ind=1:n.class+1;
    fprintf(fid,[Dxord{ind} ',' num2str(summary.table1(ind,1)) ',' num2str(round(summary.table1(ind,2))) ' (' num2str(floor(summary.table1(ind,3)))]);
    fprintf(fid,['-' num2str(ceil(summary.table1(ind,4))) ') ' num2str(round(summary.table1(ind,5))) ',' num2str(round(summary.table1(ind,6)*100))]);
    fprintf(fid,[',(' num2str(floor(summary.table1(ind,7)*10)/10) '-' num2str(ceil(summary.table1(ind,8)*10)/10) ')\n']);
end
fclose(fid);

%% Supplemental Table 1
summary.Stable1=zeros(n.class+1,9,2);
% Each class + All
% 1: Count
% 2: Age Min
% 3: Age 95% CI LB
% 4: Age 95% CI UB
% 5: Age Max
% 6: % Female
% 7: #Comorb 95% CI LB
% 8: #Comorb 95% CI UB
% 9: % Short
% Retrospective/Prospective
cnt=0;
%Count
summary.Stable1(1:n.class+1,1,1)=summary.classes ([ord n.class+1],2);
summary.Stable1(1:n.class+1,1,2)=summary.classesp([ord n.class+1],2);
for Dx=ord;
    cnt=cnt+1;
    % Retrospective
    
    %Age
    summary.Stable1(cnt,2,1)=min(data.demo(ix.classid{Dx},2));
    summary.Stable1(cnt,3,1)=mean(data.demo(ix.classid{Dx},2))-1.96*std(data.demo(ix.classid{Dx},2))/sqrt(length(ix.classid{Dx}));
    summary.Stable1(cnt,4,1)=mean(data.demo(ix.classid{Dx},2))+1.96*std(data.demo(ix.classid{Dx},2))/sqrt(length(ix.classid{Dx}));
    summary.Stable1(cnt,5,1)=max(data.demo(ix.classid{Dx},2));
    %Sex
    summary.Stable1(cnt,6,1)=mean(data.demo(ix.classid{Dx},1));
    %Comorb
    summary.Stable1(cnt,7,1)=mean(data.demo(ix.classid{Dx},3))-1.96*std(data.demo(ix.classid{Dx},3))/sqrt(length(ix.classid{Dx}));
    summary.Stable1(cnt,8,1)=mean(data.demo(ix.classid{Dx},3))+1.96*std(data.demo(ix.classid{Dx},3))/sqrt(length(ix.classid{Dx}));
    % Short vs Long
    summary.Stable1(cnt,9,1)=length(intersect(ix.classid{Dx},ix.ShortRoS))/summary.Stable1(cnt,2,1);
    
    %Prospective
    
    %Age
    summary.Stable1(cnt,2,2)=min(data.demop(ix.pclassid{Dx},2));
    summary.Stable1(cnt,3,2)=mean(data.demop(ix.pclassid{Dx},2))-1.96*std(data.demop(ix.pclassid{Dx},2))/sqrt(length(ix.pclassid{Dx}));
    summary.Stable1(cnt,4,2)=mean(data.demop(ix.pclassid{Dx},2))+1.96*std(data.demop(ix.pclassid{Dx},2))/sqrt(length(ix.pclassid{Dx}));
    summary.Stable1(cnt,5,2)=max(data.demop(ix.pclassid{Dx},2));
    %Sex
    summary.Stable1(cnt,6,2)=mean(data.demop(ix.pclassid{Dx},1));
    %Comorb
    summary.Stable1(cnt,7,2)=mean(data.demop(ix.pclassid{Dx},3))-1.96*std(data.demop(ix.pclassid{Dx},3))/sqrt(length(ix.pclassid{Dx}));
    summary.Stable1(cnt,8,2)=mean(data.demop(ix.pclassid{Dx},3))+1.96*std(data.demop(ix.pclassid{Dx},3))/sqrt(length(ix.pclassid{Dx}));
    % Short vs Long
    summary.Stable1(cnt,9,2)=length(intersect(ix.pclassid{Dx},ix.pShortRoS))/summary.Stable1(cnt,2,2);
end
% Retrospective
%Age
summary.Stable1(n.class+1,2,1)=min(data.demo(:,2));
summary.Stable1(n.class+1,3,1)=mean(data.demo(:,2))-1.96*std(data.demo(:,2))/sqrt(summary.Stable1(n.class+1,1,1));
summary.Stable1(n.class+1,4,1)=mean(data.demo(:,2))+1.96*std(data.demo(:,2))/sqrt(summary.Stable1(n.class+1,1,1));
summary.Stable1(n.class+1,5,1)=max(data.demo(:,2));
%Sex
summary.Stable1(n.class+1,6,1)=mean(data.demo(:,1));
%Comorb
summary.Stable1(n.class+1,7,1)=mean(data.demo(:,3))-1.96*std(data.demo(:,3))/sqrt(summary.Stable1(n.class+1,1,2));
summary.Stable1(n.class+1,8,1)=mean(data.demo(:,3))+1.96*std(data.demo(:,3))/sqrt(summary.Stable1(n.class+1,1,2));
% Short vs Long
summary.Stable1(n.class+1,9,1)=length(ix.ShortRoS)/summary.Stable1(n.class+1,1,1);
% Prospective
%Age
summary.Stable1(n.class+1,2,2)=min(data.demop(:,2));
summary.Stable1(n.class+1,3,2)=mean(data.demop(:,2))-1.96*std(data.demop(:,2))/sqrt(summary.Stable1(n.class+1,1,2));
summary.Stable1(n.class+1,4,2)=mean(data.demop(:,2))+1.96*std(data.demop(:,2))/sqrt(summary.Stable1(n.class+1,1,2));
summary.Stable1(n.class+1,5,2)=max(data.demop(:,2));
%Sex
summary.Stable1(n.class+1,6,2)=mean(data.demop(:,1));
%Comorb
summary.Stable1(n.class+1,7,2)=mean(data.demop(:,3))-1.96*std(data.demop(:,3))/sqrt(summary.Stable1(n.class+1,1,2));
summary.Stable1(n.class+1,8,2)=mean(data.demop(:,3))+1.96*std(data.demop(:,3))/sqrt(summary.Stable1(n.class+1,1,2));
% Short vs Long
summary.Stable1(n.class+1,9,2)=length(ix.pShortRoS)/summary.Stable1(n.class+1,1,2);

fid=fopen(dirs.Stable1,'w');
fprintf(fid,'Diagnosis,Dataset,Count,Age min (95 CI) max,Female,#Comorbid (95 CI),Short \n');
Dxord={'PNES','Mixed PNES+ES','Inconclusive','Physiologic','ES','All Patients'};
Dataset={'Retro','Prosp'};
for ind=1:n.class+1;
    for knd=1:2
        if knd==1
            fprintf(fid,[Dxord{ind} ',' Dataset{knd}]);
        else
            fprintf(fid,[',' Dataset{knd}]);
        end
        fprintf(fid,[',' num2str(summary.Stable1(ind,1,knd)) ',' num2str(round(summary.Stable1(ind,2,knd))) ' (' num2str(floor(summary.Stable1(ind,3,knd)))]);
        fprintf(fid,['-' num2str(ceil(summary.Stable1(ind,4,knd))) ') ' num2str(round(summary.Stable1(ind,5,knd))) ',' num2str(round(summary.Stable1(ind,6,knd)*100))]);
        fprintf(fid,[',(' num2str(floor(summary.Stable1(ind,7,knd)*10)/10) '-' num2str(ceil(summary.Stable1(ind,8,knd)*10)/10) '),' num2str(round(summary.Stable1(ind,9,knd)*100)) '\n']);
    end
end
fclose(fid);

%% Symptom clustering
[coeff,score,latent,tsquared,explained]=pca(data.all);
    
