%% Loading BinReg Results and Making it into a pretty figure
% Dependent on the RoS_*.m files, then run through the R script

dirs.home='/Users/wkerr/Dropbox/RoS_ES/Analysis/';
dirs.BinRegCoef    =[dirs.home 'RoS_BinRegCoef.csv'];
dirs.ixn.BinRegCoef=[dirs.home 'RoS_BinRegCoefi.csv'];

%% Without Interaction Terms
fidb=fopen(dirs.BinRegCoef,'r');
d=textscan(fidb,'%s %f %f %f %f %f','Headerlines',1,'Delimiter',',');
fclose(fidb);

ix.OR=2;
ix.SE=3;
ix.ps=5;
ORs=d{ix.OR};
SEs=d{ix.SE};
PVs=d{ix.ps};

Freqs=zeros(5,3);
% 5 Classes
% Mean, LB, UB
for cnd=1:5
    if cnd==1
        Freqs(cnd,1)=invlogit(ORs(cnd));
        Freqs(cnd,2)=abs(Freqs(cnd,1)-invlogit(ORs(cnd)-SEs(cnd)));
        Freqs(cnd,3)=abs(Freqs(cnd,1)-invlogit(ORs(cnd)+SEs(cnd)));
    else
        Freqs(cnd,1)=invlogit(ORs(1)+ORs(cnd));
        Freqs(cnd,2)=abs(Freqs(cnd,1)-invlogit(ORs(1)+ORs(cnd)-SEs(cnd)));
        Freqs(cnd,3)=abs(Freqs(cnd,1)-invlogit(ORs(1)+ORs(cnd)+SEs(cnd)));
    end
end
figure;
% ord=[5,3,4,2,1];
ord=[2,4,5,3,1];
bar5=barh(Freqs(ord,1),'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
hold on
ebs3=errbar(Freqs(ord,1),1:5,Freqs(ord,2),Freqs(ord,3),'horiz','LineWidth',5,'Color',[0 0 0]);
hold off
set(gca,'fontsize',18);
labs.Dx={'ES','PNES','PSLE','PNES+ES','Inconclusive'};
set(gca,'yticklabel',{labs.Dx{ord}});
set(gca,'xlim',[0 0.25],'xtick',0:0.05:.25,'xticklabel',{'0%','5%','10%','15%','20%','25%'});
xlabel('Positive RoS Responses');

%% Calculate Mixture
% I=XP+(1-X)E
% I: RoS% for Inconclusive
% P: RoS% for PNES (+ES)
% E: RoS$ for ES
% X: % mixture of PNES(+ES)/ES in Inconclusives
% rearranges to
% X=(E-I)/(E-P)
% Technically should combine P and Mixed based on a weighted sum, but this is a good enough
% approximation
% Could get 95% CI by simulation? - that would be a non-trivial simulation
% because I'd need to use the SE of the ORs instead of just counts
Mix=(Freqs(1,1)-Freqs(5,1))/(Freqs(1,1)-Freqs(2,1));

%% With Interaction
fidb=fopen(dirs.ixn.BinRegCoef,'r');
d=textscan(fidb,'%s %f %f %f %f %f','Headerlines',1,'Delimiter',',');
fclose(fidb);

ix.OR=2;
ix.SE=3;
ix.ps=5;
ix.Sex=6;
ix.Ixn=6;
ORs=d{ix.OR};
SEs=d{ix.SE};
PVs=d{ix.ps};

Freqs=zeros(5,2,3);
% 5 Classes
% Female and Male
% Mean, LB, UB
for cnd=1:5
    for gnd=1:2
        if cnd==1 && gnd==1 % Male and ES
            Freqs(cnd,gnd,1)=invlogit(ORs(cnd));
            Freqs(cnd,gnd,2)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(cnd)-SEs(cnd)));
            Freqs(cnd,gnd,3)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(cnd)+SEs(cnd)));
        else
            if gnd==1 % Male Patients
                Freqs(cnd,gnd,1)=invlogit(ORs(1)+ORs(cnd));
                Freqs(cnd,gnd,2)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(1)+ORs(cnd)-SEs(cnd)));
                Freqs(cnd,gnd,3)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(1)+ORs(cnd)+SEs(cnd)));
            else % Female Patients
                if cnd==1 % Female and ES
                    Freqs(cnd,gnd,1)=invlogit(ORs(1)+ORs(ix.Sex));
                    Freqs(cnd,gnd,2)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(1)+ORs(ix.Sex)-SEs(ix.Sex)));
                    Freqs(cnd,gnd,3)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(1)+ORs(ix.Sex)+SEs(ix.Sex)));
                else
                    Freqs(cnd,gnd,1)=invlogit(ORs(1)+ORs(cnd)+ORs(cnd+ix.Ixn)+ORs(ix.Sex));
                    Freqs(cnd,gnd,2)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(1)+ORs(ix.Sex)+ORs(cnd)+ORs(cnd+ix.Ixn)-sqrt(SEs(ix.Sex)^2+SEs(cnd+ix.Ixn)^2)));
                    Freqs(cnd,gnd,3)=abs(Freqs(cnd,gnd,1)-invlogit(ORs(1)+ORs(ix.Sex)+ORs(cnd)+ORs(cnd+ix.Ixn)+sqrt(SEs(ix.Sex)^2+SEs(cnd+ix.Ixn)^2)));
                end
            end
        end
    end
end
figure;
% ord=[5,3,4,2,1];
ord=[2,4,5,3,1];
bar5=barh([Freqs(ord,1,1);Freqs(ord,2,1)],'BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
hold on
ebs3=errbar([Freqs(ord,1,1);Freqs(ord,2,1)],1:10,[Freqs(ord,1,2);Freqs(ord,2,2)],[Freqs(ord,1,3);Freqs(ord,2,3)],'horiz','LineWidth',5,'Color',[0 0 0]);
hold off
set(gca,'fontsize',18);
labs.ixn.Dx={'M+ES','M+PNES','M+PSLE','M+PNES+ES','M+Inconclusive','F+ES','F+PNES','F+PSLE','F+PNES+ES','F+Inconclusive'};
set(gca,'yticklabel',{labs.ixn.Dx{[ord,ord+5]}});
set(gca,'ylim',[0.5 10.5]);
set(gca,'xlim',[0 0.30],'xtick',0:0.05:.25,'xticklabel',{'0%','5%','10%','15%','20%','25%','30%'});
xlabel('Positive RoS Responses');

figure;
% ord=[5,3,4,2,1];
ord =[2,4,5,3,1];
bar5=barh(reshape(Freqs(ord,:,1)',[1 10])','BarWidth',1,'FaceColor',[0.5 0.5 0.5],'EdgeColor',[1 1 1]);
hold on
ebs3=errbar(reshape(Freqs(ord,:,1)',[1 10])',1:10,reshape(Freqs(ord,:,2)',[1 10])',reshape(Freqs(ord,:,3)',[1 10])','horiz','LineWidth',5,'Color',[0 0 0]);
hold off
set(gca,'fontsize',18);
labs.ixn.Dx={'M+ES','F+ES','M+PNES','F+PNES','M+PSLE','F+PSLE','M+PNES+ES','F+PNES+ES','M+Inconclusive','F+Inconclusive'};
set(gca,'yticklabel',{labs.ixn.Dx{reshape([ord*2-1;ord*2],[1 10])'}});
set(gca,'ylim',[0.5 10.5]);
set(gca,'xlim',[0 0.30],'xtick',0:0.05:.25,'xticklabel',{'0%','5%','10%','15%','20%','25%','30%'});
xlabel('Positive RoS Responses');