%% Load the RoS Prospective Data
% Troubleshoot points
% 1. Check for doubles between prospective and retrospective (MRNs)
% 2. Predict the prospective diagnoses, compare to the actual diagnoses
% 3. Permutations
% 4. LOESS on prospective
% 5. Add Prospective to Retrospective for descriptive analysis

%% Set up variables
dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.home=[dirs.base 'Dropbox/RoS_ES/Analysis/'];
dirs.dataprosp=[dirs.home 'ProspectiveRoSData160627.csv'];
dirs.parff    =[dirs.home 'ProspectiveArff'];
% dirs.table1 need to make them
dirs.sigqs=[dirs.home 'RetroSigQs.csv'];

n.perms=1; % currently perfs default to the null solution
% n.perms should be 10,000 for p<0.05, and 50,000 for p<0.01

%% Get Prospective Data
% Get Headers
fid=fopen(dirs.dataprosp,'r');
h=textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Headerlines',1,'Delimiter',',');
fclose(fid);
n.col=length(h);
pheads=cell(n.col,1);
for ind=1:n.col
    pheads{ind}=h{ind}(1);
end
ix.MRN=1;
ix.Dx=2;
ix.Age=3;
ix.Gender=4;
ix.Comorb=5;
ix.Colmin=8;
ix.Colmax=85;
ix.RoSType=7;
n.RoSColp=length(ix.Colmin:ix.Colmax);
n.RoSSho=n.RoSColp-3;
if exist('n.RoSCol','var')
    if n.RoSCol~=n.RosColp
        error 'there is an alignment problem'
    end
end

% Get Prospective Data
fid=fopen(dirs.dataprosp,'r');
d=textscan(fid,'%f %f %f %s %f %s %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s %f','Headerlines',2,'Delimiter',',');
fclose(fid);

ix.subp=find(~isnan(d{1}));
n.subp=length(ix.subp);
ix.pLongRoS  =find(strcmp(d{ix.RoSType},'Long'));
ix.pShortRoS =find(strcmp(d{ix.RoSType},'Short'));
n.RoSShop=n.RoSSho;
data.pMRN=d{1}(ix.subp);

% Get RoS Data
data.prosp=zeros(n.subp,n.RoSColp);
cnt=0;
for cnd=ix.Colmin:ix.Colmax
    cnt=cnt+1;
    data.prosp(:,cnt)=d{cnd}(ix.subp);
end
ix.fix=isnan(data.prosp);
data.prosp(ix.fix)=0;
data.prospsum=zeros(size(data.prosp,1),2);
data.prospsum(:,1)=sum(data.prosp,2);
data.prospsum(:,2)=n.RoSColp;
data.percp=zeros(n.subp,1);
for snd=1:n.subp
    if intersect(ix.pLongRoS,snd)
        data.percp(snd)=data.prospsum(snd,1)/n.RoSColp;
        data.prospsum(snd,2)=n.RoSColp;
    elseif intersect(ix.pShortRoS,snd)
        data.percp(snd)=data.prospsum(snd,1)/n.RoSShop;
        data.prospsum(snd,2)=n.RoSShop;
    end
end
% Get Gender/Age Data
data.demop=zeros(n.subp,3);
data.demop(:,1)=strcmp(d{ix.Gender}(ix.subp),'F');
data.demop(:,2)=d{ix.Age}(ix.subp);
data.demop(:,3)=d{ix.Comorb}(ix.subp);

% Class information
data.classp=d{ix.Dx}(ix.subp);
%simplify class
fprintf('Simplying all ES to one type\n');
tmp=find(data.classp>0);
data.classp(tmp)=1;

%% Summary Statistics
n.classp=length(unique(data.classp));
n.class=n.classp;
summary.classesp=zeros(n.classp+1,5);
% 1: Class value
% 2: n
% 3: Average Positive
% 4: Std Positive/sqrt(n)
% 5: % above 17%
summary.classesp(1:n.classp,1)=unique(data.classp);
summary.classesp(n.classp+1,1)=411; % all

ix.pclassid=cell(n.classp+1,1);
for ind=1:n.classp+1
    if ind>n.classp
        ix.pclassid{ind}=ix.pclassid{1};
        for jnd=2:n.classp
            ix.pclassid{ind}=union(ix.pclassid{ind},ix.pclassid{jnd});
        end
    else
        ix.pclassid{ind}=find(data.classp==summary.classesp(ind,1));
    end
    summary.classesp(ind,2)=length(ix.pclassid{ind});
    summary.classesp(ind,3)=mean(data.prospsum(ix.pclassid{ind},1));
    summary.classesp(ind,4)=std( data.prospsum(ix.pclassid{ind},1))/sqrt(summary.classesp(ind,2));
    summary.classesp(ind,5)=sum(data.percp(ix.pclassid{ind})>0.17)/summary.classesp(ind,2);
end

%% Predictions
% Set up variables
ix.pDxPNES=find(summary.classesp(1:n.class,1)==-2);
n.pPNES=length(ix.pDxPNES);
ix.pDxES  =find(summary.classesp(1:n.class,1)>0); 
n.pES  =length(ix.pDxES);
n.pPNESSho=length(intersect(ix.pclassid{ix.pDxPNES},ix.pShortRoS));
n.pESSho  =length(intersect(ix.pclassid{ix.pDxES}  ,ix.pShortRoS));
ix.phasdx=union(ix.pclassid{ix.pDxPNES},ix.pclassid{ix.pDxES});

%output to weka
create_arff(dirs.parff,[data.demop(ix.phasdx,:), data.prosp(ix.phasdx,:)],data.classp(ix.phasdx),2);

% L1 Regularized using Individual Complaint
modeldata.X=[data.demo(ix.hasdx,1) data.retro(ix.hasdx,:)];
modeldata.Y=1*(data.class(ix.hasdx)>0);
modeldata.Xp=[data.demop(ix.phasdx,1) data.prosp(ix.phasdx,:)];
modeldata.Yp=1*(data.classp(ix.phasdx)>0);
model=train(modeldata.Y,sparse(modeldata.X),'-s 6 -q');
[lab,ac,dc]=predict(modeldata.Yp,sparse(modeldata.Xp),model,'-q');

% PCA filtered using Individual Complaint
[coeff,score,latent,tsquared,explained]=pca([data.demo(ix.hasdx,1) data.retro(ix.hasdx,:)]);
[tmp1,tmp2,explained]=pcacov([data.demo(ix.hasdx,1) data.retro(ix.hasdx,:)]);
explained2=zeros(size(explained));
for ind=1:length(explained)
    explained2(ind)=sum(explained(1:ind));
end
explained2=explained2/sum(explained);
n.pca=10;
recon=inv(coeff);
modeldata.X=modeldata.X*recon(:,1:n.pca);
modeldata.Y=1*(data.class(ix.hasdx)>0);
[pcar.b,pcar.dev,pcar.stats]=glmfit(modeldata.X,modeldata.Y,'binomial');
modeldata.Xp=[data.demop(ix.phasdx,1) data.prosp(ix.phasdx,:)]*recon(:,1:n.pca);
modeldata.Yp=1*(data.classp(ix.phasdx)>0);
[data.pca.predyhat,data.pca.predylo,data.pca.predyhi]=glmval(pcar.b,modeldata.Xp,'logit',pcar.stats);
data.pca.predy   =(data.pca.predyhat>=0.5)*2-1;

% Logistic Regression using Percent, Gender and # Comorbid
modeldata.X=[data.perc(ix.hasdx) data.demo(ix.hasdx,1) data.demo(ix.hasdx,3)];
modeldata.Y=1*(data.class(ix.hasdx)>0);
[b,dev,stats]=glmfit(modeldata.X,modeldata.Y,'binomial');
data.predytru=(data.classp(ix.phasdx)+2)/3*2-1;
modeldata.Xp=[data.percp(ix.phasdx) data.demop(ix.phasdx,1) data.demop(ix.phasdx,3)];
[data.predyhat,data.predylo,data.predyhi]=glmval(b,modeldata.Xp,'logit',stats);
data.predy   =(data.predyhat>=0.5)*2-1;

% Logistic Regression using Percent, Ixn Sex/Percent, Gender and # Comorbid
modeldata.X=[data.perc(ix.hasdx), data.perc(ix.hasdx).*data.demo(ix.hasdx,1), data.demo(ix.hasdx,1), data.demo(ix.hasdx,3)];
modeldata.Y=1*(data.class(ix.hasdx)>0);
[bixn,devixn,statsixn]=glmfit(modeldata.X,modeldata.Y,'binomial');
data.predytru=(data.classp(ix.phasdx)+2)/3*2-1;
modeldata.Xp=[data.percp(ix.phasdx), data.percp(ix.phasdx).*data.demop(ix.phasdx,1), data.demop(ix.phasdx,1), data.demop(ix.phasdx,3)];
[data.ixn.predyhat,data.ixn.predylo,data.ixn.predyhi]=glmval(bixn,modeldata.Xp,'logit',statsixn);
data.ixn.predy   =(data.predyhat>=0.5)*2-1;

% Inconclusive between model
data.predyb  =(data.predyhat<=perc.ilth)*-1+(data.predyhat>=perc.iuth);

%Inconclusive Range

% Summary Statistics for logistic regression
summary.perf=zeros(5,3,4);
% Index 1:
% 1:Accuracy
% 2:Sensitivity
% 3:Specificity
% 4:PPV
% 5:NPV
% Index 2:
% Mean
% 95% LB
% 95% UB
% Index 3:
% 1: Model
% 2: Balanced Accuracy Model
% 3: Robles 17% Cutoff
% 4: PCA Model

% Model
summary.perf(1,1,1)=mean(data.predy.*data.predytru>0);
summary.perf(1,2,1)=binoinv(0.025,length(data.predy),summary.perf(1,1,1))/length(data.predy);
summary.perf(1,3,1)=binoinv(0.975,length(data.predy),summary.perf(1,1,1))/length(data.predy);
ix.pDxESsm=find(data.predytru==1);
ix.pDxPNESsm=find(data.predytru==-1);
summary.perf(2,1,1)=mean(data.predy(ix.pDxESsm).*data.predytru(ix.pDxESsm)>0);
summary.perf(2,2,1)=binoinv(0.025,length(ix.pDxESsm),summary.perf(2,1,1))/length(ix.pDxESsm);
summary.perf(2,3,1)=binoinv(0.975,length(ix.pDxESsm),summary.perf(2,1,1))/length(ix.pDxESsm);
summary.perf(3,1,1)=mean(data.predy(ix.pDxPNESsm).*data.predytru(ix.pDxPNESsm)>0);
summary.perf(3,2,1)=binoinv(0.025,length(ix.pDxPNESsm),summary.perf(3,1,1))/length(ix.pDxPNESsm);
summary.perf(3,3,1)=binoinv(0.975,length(ix.pDxPNESsm),summary.perf(3,1,1))/length(ix.pDxPNESsm);
ix.pPP=find(data.predy==1);
ix.pNP=find(data.predy==-1);
summary.perf(4,1,1)=mean(data.predy(ix.pPP).*data.predytru(ix.pPP)>0);
summary.perf(4,2,1)=binoinv(0.025,length(ix.pPP),summary.perf(4,1,1))/length(ix.pPP);
summary.perf(4,3,1)=binoinv(0.975,length(ix.pPP),summary.perf(4,1,1))/length(ix.pPP);
summary.perf(5,1,1)=mean(data.predy(ix.pNP).*data.predytru(ix.pNP)>0);
summary.perf(5,2,1)=binoinv(0.025,length(ix.pNP),summary.perf(5,1,1))/length(ix.pNP);
summary.perf(5,3,1)=binoinv(0.975,length(ix.pNP),summary.perf(5,1,1))/length(ix.pNP);
 
% Balanced Accuracy model
summary.perf(1,1,2)=mean(data.predyb.*data.predytru>0);
summary.perf(1,2,2)=binoinv(0.025,length(data.predyb),summary.perf(1,1,2))/length(data.predyb);
summary.perf(1,3,2)=binoinv(0.975,length(data.predyb),summary.perf(1,1,2))/length(data.predyb);
ix.pDxESsm=find(data.predytru==1);
ix.pDxPNESsm=find(data.predytru==-1);
summary.perf(2,1,2)=mean(data.predyb(ix.pDxESsm).*data.predytru(ix.pDxESsm)>0);
summary.perf(2,2,2)=binoinv(0.025,length(ix.pDxESsm),summary.perf(2,1,2))/length(ix.pDxESsm);
summary.perf(2,3,2)=binoinv(0.975,length(ix.pDxESsm),summary.perf(2,1,2))/length(ix.pDxESsm);
summary.perf(3,1,2)=mean(data.predyb(ix.pDxPNESsm).*data.predytru(ix.pDxPNESsm)>0);
summary.perf(3,2,2)=binoinv(0.025,length(ix.pDxPNESsm),summary.perf(3,1,2))/length(ix.pDxPNESsm);
summary.perf(3,3,2)=binoinv(0.975,length(ix.pDxPNESsm),summary.perf(3,1,2))/length(ix.pDxPNESsm);
ix.pPP=find(data.predyb==1);
ix.pNP=find(data.predyb==-1);
summary.perf(4,1,2)=mean(data.predyb(ix.pPP).*data.predytru(ix.pPP)>0);
summary.perf(4,2,2)=binoinv(0.025,length(ix.pPP),summary.perf(4,1,2))/length(ix.pPP);
summary.perf(4,3,2)=binoinv(0.975,length(ix.pPP),summary.perf(4,1,2))/length(ix.pPP);
summary.perf(5,1,2)=mean(data.predyb(ix.pNP).*data.predytru(ix.pNP)>0);
summary.perf(5,2,2)=binoinv(0.025,length(ix.pNP),summary.perf(5,1,2))/length(ix.pNP);
summary.perf(5,3,2)=binoinv(0.975,length(ix.pNP),summary.perf(5,1,2))/length(ix.pNP);

% PCA model
summary.perf(1,1,4)=mean(data.pca.predy.*data.predytru>0);
summary.perf(1,2,4)=binoinv(0.025,length(data.pca.predy),summary.perf(1,1,4))/length(data.pca.predy);
summary.perf(1,3,4)=binoinv(0.975,length(data.pca.predy),summary.perf(1,1,4))/length(data.pca.predy);
ix.pDxESsm=find(data.predytru==1);
ix.pDxPNESsm=find(data.predytru==-1);
summary.perf(2,1,4)=mean(data.pca.predy(ix.pDxESsm).*data.predytru(ix.pDxESsm)>0);
summary.perf(2,2,4)=binoinv(0.025,length(ix.pDxESsm),summary.perf(2,1,4))/length(ix.pDxESsm);
summary.perf(2,3,4)=binoinv(0.975,length(ix.pDxESsm),summary.perf(2,1,4))/length(ix.pDxESsm);
summary.perf(3,1,4)=mean(data.pca.predy(ix.pDxPNESsm).*data.predytru(ix.pDxPNESsm)>0);
summary.perf(3,2,4)=binoinv(0.025,length(ix.pDxPNESsm),summary.perf(3,1,4))/length(ix.pDxPNESsm);
summary.perf(3,3,4)=binoinv(0.975,length(ix.pDxPNESsm),summary.perf(3,1,4))/length(ix.pDxPNESsm);
ix.pPP=find(data.pca.predy==1);
ix.pNP=find(data.pca.predy==-1);
summary.perf(4,1,4)=mean(data.pca.predy(ix.pPP).*data.predytru(ix.pPP)>0);
summary.perf(4,2,4)=binoinv(0.025,length(ix.pPP),summary.perf(4,1,4))/length(ix.pPP);
summary.perf(4,3,4)=binoinv(0.975,length(ix.pPP),summary.perf(4,1,4))/length(ix.pPP);
summary.perf(5,1,4)=mean(data.pca.predy(ix.pNP).*data.predytru(ix.pNP)>0);
summary.perf(5,2,4)=binoinv(0.025,length(ix.pNP),summary.perf(5,1,4))/length(ix.pNP);
summary.perf(5,3,4)=binoinv(0.975,length(ix.pNP),summary.perf(5,1,4))/length(ix.pNP);

%Permutations with Logistic
perfperms=zeros(5,n.perms);
for pnd=1:n.perms
    r=randperm(n.dataanddx);
    modeldata.Yperm=modeldata.Y(r);
    [bperm,devperm,statsperm]=glmfit(modeldata.X,modeldata.Yperm,'binomial');
    perm.yhat=glmval(bperm,modeldata.Xp,'logit',statsperm);
    perm.predy   =(perm.yhat>=0.5)*2-1;
    perfperms(1,pnd)=mean(perm.predy.*data.predytru>0);
    perfperms(2,pnd)=mean(perm.predy(ix.pDxESsm).*data.predytru(ix.pDxESsm)>0);
    perfperms(3,pnd)=mean(perm.predy(ix.pDxPNESsm).*data.predytru(ix.pDxPNESsm)>0);
    iperm.pPP=find(perm.predy==1);
    iperm.pNP=find(perm.predy==-1);
    perfperms(4,pnd)=mean(perm.predy(iperm.pPP).*data.predytru(iperm.pPP)>0);
    perfperms(5,pnd)=mean(perm.predy(iperm.pNP).*data.predytru(iperm.pNP)>0);
end

%% Percent-Based Analysis
% ROC curve
n.pdataanddx=length(ix.classid{ix.pDxPNES})+length(ix.classid{ix.pDxES});
thresh.pperc=unique(data.percp);
n.perc.pthresh=length(thresh.pperc);
data.pROC=zeros(n.perc.pthresh,2);
data.pAUC=0;
% 1: TPR (sens for PNES)
% 2: FPR (1-spec for ES)
for tnd=1:n.perc.pthresh
    data.pROC(tnd,1)=sum(data.percp(ix.pclassid{ix.pDxPNES})>=thresh.pperc(tnd))/summary.classesp(ix.pDxPNES,2);
    data.pROC(tnd,2)=sum(data.percp(ix.pclassid{ix.pDxES})>thresh.pperc(tnd))/summary.classesp(ix.pDxES,2);
    if tnd>1
        data.pAUC=data.pAUC+(1-data.pROC(tnd,2))*(data.pROC(tnd-1,1)-data.pROC(tnd,1));
    end
end
perc.pbacc=(data.pROC(:,1)+(1-data.pROC(:,2)))/2;
[perc.pmaxbacc,tmp]=max(perc.pbacc);
perc.pmaxbath=thresh.pperc(tmp);
perc.pmaxbasens=data.pROC(tmp,1);
perc.pmaxbaspec=data.pROC(tmp,2);
perc.pacc =(data.pROC(:,1)*summary.classesp(ix.pDxPNES,2)+(1-data.pROC(:,2))*summary.classesp(ix.pDxES,2))/(summary.classesp(ix.pDxPNES,2)+summary.classesp(ix.pDxES,2));
[perc.pmaxacc,tmp] =max(perc.pacc);
perc.paccp=(1-binocdf(perc.pmaxacc*n.pdataanddx,n.pdataanddx,max(summary.classesp([ix.pDxPNES,ix.pDxES],2))/n.pdataanddx))*2;
perc.pmaxacth=thresh.pperc(tmp);
perc.pmaxasen=data.pROC(tmp,1);
perc.pmaxaspe=data.pROC(tmp,2);
perc.pAUC    =data.pAUC;
data.pSEQ1=perc.pAUC/(2-perc.pAUC);
data.pSEQ2=2*perc.pAUC^2/(1+perc.pAUC);
data.pSEAUC=sqrt((perc.pAUC*(1-perc.pAUC)+(n.pPNES-1)*(data.pSEQ1-perc.pAUC^2)+(n.pES-1)*(data.pSEQ2-perc.pAUC^2))/n.pPNES/n.pES);

figure
pl1=plot(data.pROC(:,2),data.pROC(:,1),'color','black','LineWidth',2);
title('Prospective')
xlabel('Percent ES above threshold (false positive rate)');
ylabel('Percent PNES above threshold (true positive rate)');
set(gca,'xlim',[0 1],'ylim',[0 1]);
set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
axis square

% Pan-Positive Statistics
perc.panthresh=0.47;
iy.panthresh=min(find(thresh.pperc>perc.panthresh));
perc.ppanPNES=sum(data.percp(ix.pclassid{ix.pDxPNES})>=thresh.pperc(iy.panthresh));
perc.ppanES  =sum(data.percp(ix.pclassid{ix.pDxES})>=thresh.pperc(iy.panthresh));
n.pPNES=length(ix.pclassid{ix.pDxPNES});
n.pES  =length(ix.pclassid{ix.pDxES});
iy.panthreshr=min(find(thresh.perc>perc.panthresh));
perc.panPNES=sum(data.perc(ix.classid{ix.DxPNES})>=thresh.perc(iy.panthreshr));
perc.panES  =sum(data.perc(ix.classid{ix.DxES})>=thresh.perc(iy.panthreshr));
n.PNES =length(ix.classid{ix.DxPNES});
n.ES   =length(ix.classid{ix.DxES});

figure;
ssigma=0.02; % Gaussian window

% make exact figure
tmps.percvals=unique(data.percp);
tmps.perchist=zeros(length(tmps.percvals),2);
for ind=1:length(tmps.percvals)
    tmps.perchist(ind,1)=sum(data.percp(ix.pclassid{ix.pDxPNES})==tmps.percvals(ind));
    tmps.perchist(ind,2)=sum(data.percp(ix.pclassid{ix.pDxES})==tmps.percvals(ind));
end
% add smoothing
perc.val=0:1/size(data.prosp,2):1;
n.percvals=length(perc.val);
perc.ploess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
% Gaussian smoothing kernel applied onto tmps.perchist
for ind=1:n.percvals
    for jnd=1:length(tmps.percvals)
        perc.ploess(ind,1)=perc.ploess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
        perc.ploess(ind,2)=perc.ploess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
        perc.ploess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
    end
end
perc.ploess=perc.ploess./repmat(perc.ploess(:,3),[1 3]);
perc.pfreqbars=zeros(n.percvals,3);
perc.pfreqbars(:,2)=perc.ploess(:,1)./perc.ploess(:,2);
for ind=1:n.percvals
    if perc.pfreqbars(ind,2)==1
        perc.pfreqbars(ind,[1 3])=abs(perc.pfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.ploess(ind,2)),1-1/2/floor(perc.ploess(ind,2)))/floor(perc.ploess(ind,2)));
    else
        perc.pfreqbars(ind,[1 3])=abs(perc.pfreqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.ploess(ind,2)),perc.pfreqbars(ind,2))/floor(perc.ploess(ind,2)));
    end
    if perc.ploess(ind,2)<2
        perc.pfreqbars(ind,:)=NaN;
    end
end
hold on
pl4=plot(perc.val,perc.ploess(:,1)./perc.ploess(:,2),'Color',[0 0 0],'LineWidth',2);
ebs=errbar(perc.val,perc.pfreqbars(:,2),perc.pfreqbars(:,1),perc.pfreqbars(:,3),'LineWidth',3,'Color',[0 0 0]);
hold off
% removeErrorBarEnds(ebs);

title('Prospective');
ylabel('Percent Patients with PNES vs ES');
xlabel('Percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[0 0.6],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

% >= LOESS Figure
tmpsGT.ppercvals=unique(data.percp);
tmpsGT.pperchist=zeros(n.percvals,2);
perc.pfreqbarsGT=zeros(n.percvals,3);
for ind=1:n.percvals
    tmpsGT.pperchist(ind,1)=sum(data.percp(ix.pclassid{ix.pDxPNES})>=perc.val(ind));
    tmpsGT.pperchist(ind,2)=sum(data.percp(ix.pclassid{ix.pDxES})>=perc.val(ind));
    tmps.n=sum(tmpsGT.pperchist(ind,:));
    perc.pfreqbarsGT(ind,2)=tmpsGT.pperchist(ind,1)/tmps.n;
    if perc.pfreqbarsGT(ind,2)==1
        perc.pfreqbarsGT(ind,[1 3])=abs(perc.pfreqbarsGT(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(tmps.n),1-1/2/floor(tmps.n))/floor(tmps.n));
    else
        perc.pfreqbarsGT(ind,[1 3])=abs(perc.pfreqbarsGT(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(tmps.n),perc.pfreqbarsGT(ind,2))/floor(tmps.n));
    end
    if tmps.n<=2
        perc.pfreqbars(ind,:)=NaN;
    end
end

figure;
hold on
pl4=plot(perc.val,perc.pfreqbarsGT(:,2),'Color',[0 0 0],'LineWidth',2);
ebs=errbar(perc.val,perc.pfreqbarsGT(:,2),perc.pfreqbarsGT(:,1),perc.pfreqbarsGT(:,3),'LineWidth',3,'Color',[0 0 0]);
hold off

ylabel('Percent Patients with PNES vs ES');
xlabel('Greater than or equal to percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[0 0.55],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});



%% Descriptive Trend Figure - 5 classes
figure;
ssigma=0.015; % Gaussian window

% make exact figure
tmps5.percvals=unique(data.percp);
tmps5.perchist=zeros(length(tmps.percvals),n.class);
for ind=1:length(tmps5.percvals)
    for cnd=1:n.class
        tmps5.perchist(ind,cnd)=sum(data.perc(ix.classid{cnd})==tmps5.percvals(ind));
    end
end
% add smoothing
perc.val=0:1/size(data.prosp,2):1;
n.percvals=length(perc.val);
perc.p5loess=zeros(n.percvals,3,n.class); %1: freq, 2:n, 3:for norming
% Gaussian smoothing kernel applied onto tmps5.perchist
for ind=1:n.percvals
    for jnd=1:length(tmps5.percvals)
        for cnd=1:n.class
            perc.p5loess(ind,1,cnd)=perc.p5loess(ind,1,cnd)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*tmps5.perchist(jnd,cnd);
        end
        perc.p5loess(ind,2,1)=perc.p5loess(ind,2,1)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*sum(tmps5.perchist(jnd,:),2);
        perc.p5loess(ind,3,1)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
    end
end
perc.p5loess=perc.p5loess./repmat(perc.p5loess(:,3,1),[1 3 n.class]);
perc.p5freqbars=zeros(n.percvals,n.class); % Note that we don't have error bars because that would be too messy
perc.p5freqbars=squeeze(perc.p5loess(:,1,:))./repmat(perc.p5loess(:,2,1),[1 n.class]);
for ind=1:n.percvals
    if perc.p5loess(ind,2,1)<2
        perc.p5freqbars(ind,:)=NaN;
    end
end
ordcl=[2 1 4 3 5];
bar5=bar(perc.val,perc.p5freqbars(:,ordcl),'stacked','BarWidth',1);
title('Prospective');
set(gca,'fontsize',16);
ylabel('Percent of All Patients');
xlabel('Percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[-0.01 0.55],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

set(bar5(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName','PNES');
set(bar5(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName','Mixed');
set(bar5(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName','Inconclusive');
set(bar5(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName','Physio NES');
set(bar5(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName','ES');
legend1 = legend(gca,'show');

%>=

tmpsGT5.ppercvals=unique(data.percp);
tmpsGT5.pperchist=zeros(n.percvals,n.class);
perc.pfreqbarsGT5=zeros(n.percvals,n.class);
for ind=1:n.percvals
    for cnd=1:n.class
        tmpsGT5.pperchist(ind,cnd)=sum(data.percp(ix.pclassid{cnd})>=perc.val(ind));
    end
    tmps.n=sum(tmpsGT5.pperchist(ind,:));
    for cnd=1:n.class
        perc.pfreqbarsGT5(ind,cnd)=tmpsGT5.pperchist(ind,cnd)/tmps.n;
    end
end
figure
ordcl=[2 1 4 3 5];
bar5=bar(perc.val,perc.pfreqbarsGT5(:,ordcl),'stacked','BarWidth',1);
title('Prospective Data');
set(gca,'fontsize',16);
ylabel('Percent of All Patients');
xlabel('Greater than or equal to percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[-0.01 0.55],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

set(bar5(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName','PNES');
set(bar5(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName','Mixed');
set(bar5(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName','Inconclusive');
set(bar5(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName','PSLE');
set(bar5(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName','ES');
legend1 = legend(gca,'show');

%% Information for Supplemental Figure 1B
summary.pindiv=zeros(n.class+1,size(data.prosp,2),2);
% Mean
% SE
% p-PNESvsES
for jnd=1:size(data.prosp,2)
    if isempty(intersect(ix.shortmissing,jnd+5)) % is the question on the short RoS form
        for ind=1:n.class+1
            summary.pindiv(ind,jnd,1)=mean(data.prosp(ix.pclassid{ind},jnd));
            summary.pindiv(ind,jnd,2)=std(data.prosp(ix.pclassid{ind},jnd))/sqrt(length(ix.pclassid{ind}));
        end
        tmpx=[sum(data.prosp(ix.pclassid{ix.pDxPNES},jnd)),sum(data.prosp(ix.pclassid{ix.pDxES},jnd))];
        tmpn=[length(ix.pclassid{ix.pDxPNES}),length(ix.pclassid{ix.pDxES})];
    else % question is off the short RoS
        fprintf([heads{jnd+5}{1} '\n']);
        for ind=1:n.class+1
            summary.pindiv(ind,jnd,1)=mean(data.prosp(intersect(ix.pclassid{ind},ix.pShortRoS),jnd));
            summary.pindiv(ind,jnd,2)=std(data.prosp(intersect(ix.pclassid{ind},ix.pShortRoS),jnd))/sqrt(length(intersect(ix.pclassid{ind},ix.pShortRoS)));
        end
        tmpx=[sum(data.prosp(intersect(ix.pclassid{ix.pDxPNES},ix.pShortRoS),jnd)),sum(data.prosp(intersect(ix.pclassid{ix.pDxES},ix.pShortRoS),jnd))];
        tmpn=[length(intersect(ix.pclassid{ix.pDxPNES},ix.pShortRoS)),length(intersect(ix.pclassid{ix.pDxES},ix.pShortRoS))];
    end
    if tmpx(1)/tmpn(1)==tmpx(2)/tmpn(2)
        p=1;
    else
        [h,p,stat,df]=prop_test(tmpx,tmpn,true);
    end
    summary.pindiv(1,jnd,3)=p;
end
