%% Load the RoS Retrospective Data
% Troubleshoot points
% 2. Cleaning of the data.retro to remove columns that no one responsed
% positively to, and are collinear with other columns
% 3. Grouping data.retro by category

%% Set up variables
dirs.base='/Users/wkerr/';
laptop=0;
if ~exist(dirs.base,'dir')
    dirs.base='/Users/kerr/';
    laptop=1;
    if ~exist(dirs.base,'dir')
        error 'file structure needs to be modified'
    end
end
dirs.home=[dirs.base 'Dropbox/RoS_ES/Analysis/'];
dirs.dataretro=[dirs.home 'RetrospectivePtRoS160224a.csv'];
dirs.rarff    =[dirs.home 'RetrospectiveArff'];
% dirs.table1 need to make them
dirs.sigqs=[dirs.home 'RetroSigQs.csv'];

Colors5=[78 195 199;
137 88 129;
243 108 54;
199 178 158;
130 71 55]/256;

%% Load Raw Data and Parse
% Get Headers
fid=fopen(dirs.dataretro,'r');
h=textscan(fid,'%s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s %s','Headerlines',1,'Delimiter',',');
fclose(fid);
n.col=length(h);
heads=cell(n.col,1);
ix.shortmissing=[];
for ind=1:n.col
    heads{ind}=h{ind}(1);
    if ~isempty(heads{ind}{1});
        if strcmp(heads{ind}{1}(end),'*')
            ix.shortmissing=[ix.shortmissing,ind];
        end
    end
end
ix.Dx=2;
ix.Age=3;
ix.Gender=4;
ix.RoSType=6;
ix.Comorb=5;
ix.Colmin=7;
ix.Colmax=84;
n.RoSCol=length(ix.Colmin:ix.Colmax);
n.RoSSho=n.RoSCol-3;

% Get Retrospective Data
fid=fopen(dirs.dataretro,'r');
d=textscan(fid,'%f %f %f %s %f %s %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s %f','Headerlines',2,'Delimiter',',');
fclose(fid);

ix.sub=find(~isnan(d{1}));
n.sub=length(ix.sub);
ix.ToLookRoS=find(strcmp(d{ix.RoSType},''));
ix.noRoS    =find(strcmp(d{ix.RoSType},'None') | strcmp(d{ix.RoSType},'Refused'));
ix.BadRoS   =find(strcmp(d{ix.RoSType},'Confidential'));
ix.LongRoS  =find(strcmp(d{ix.RoSType},'Long') | strcmp(d{ix.RoSType},'Split'));
ix.ShortRoS =find(strcmp(d{ix.RoSType},'Short') | strcmp(d{ix.RoSType},'Short - in1st'));
ix.InelRoS  =union(ix.ToLookRoS,ix.noRoS);
ix.InelRoS  =union(ix.InelRoS,ix.BadRoS);
ix.EligRoS  =setdiff(1:n.sub,ix.InelRoS);
n.data=length(ix.EligRoS);

% Get RoS Data
data.retro=zeros(n.data,n.RoSCol);
cnt=0;
for cnd=ix.Colmin:ix.Colmax
    cnt=cnt+1;
    data.retro(:,cnt)=d{cnd}(ix.EligRoS);
end
ix.fix=isnan(data.retro);
data.retro(ix.fix)=0;
data.retrosum=zeros(size(data.retro,1),2);
data.retrosum(:,1)=sum(data.retro,2);
data.perc    =zeros(n.data,1);
cnt=0;
for snd=1:n.sub
    if intersect(ix.LongRoS,snd)
        cnt=cnt+1;
        data.perc(cnt)=data.retrosum(cnt,1)/n.RoSCol;
        data.retrosum(cnt,2)=n.RoSCol;
    elseif intersect(ix.ShortRoS,snd)
        cnt=cnt+1;
        data.perc(cnt)=data.retrosum(cnt,1)/n.RoSSho;
        data.retrosum(cnt,2)=n.RoSSho;
    end
end
% Get Gender/Age Data
data.demo=zeros(n.data,3);
data.demo(:,1)=strcmp(d{ix.Gender}(ix.EligRoS),'F');
data.demo(:,2)=d{ix.Age}(ix.EligRoS);
data.demo(:,3)=d{ix.Comorb}(ix.EligRoS);

% Class information
data.class=d{ix.Dx}(ix.EligRoS);
%simplify class
fprintf('Simplying all ES to one type\n');
tmp=find(data.class>0);
data.class(tmp)=1;

%% Summary Statistics
n.class=length(unique(data.class));
summary.classes=zeros(n.class+1,5);
% 1: Class value
% 2: n
% 3: Average Positive
% 4: Std Positive/sqrt(n)
% 5: % above 17%
summary.classes(1:n.class,1)=unique(data.class);
summary.classes(n.class+1,1)=411; % all

ix.classid=cell(n.class+1,1);
for ind=1:n.class+1
    if ind>n.class
        ix.classid{ind}=ix.classid{1};
        for jnd=2:n.class
            ix.classid{ind}=union(ix.classid{ind},ix.classid{jnd});
        end
    else
        ix.classid{ind}=find(data.class==summary.classes(ind,1));
    end
    summary.classes(ind,2)=length(ix.classid{ind});
    summary.classes(ind,3)=mean(data.retrosum(ix.classid{ind},1));
    summary.classes(ind,4)=std( data.retrosum(ix.classid{ind},1))/sqrt(summary.classes(ind,2));
    summary.classes(ind,5)=sum(data.perc(ix.classid{ind})>0.17)/summary.classes(ind,2);
end

%% Percent-Based Analysis
% ROC curve
ix.DxPNES=find(summary.classes(1:n.class,1)==-2);
ix.DxES  =find(summary.classes(1:n.class,1)>0); 
ix.hasdx=union(ix.classid{ix.DxPNES},ix.classid{ix.DxES});

%output to Weka
create_arff(dirs.rarff,[data.demo(ix.hasdx,:), data.retro(ix.hasdx,:)],data.class(ix.hasdx),2);

n.PNESSho=length(intersect(ix.classid{ix.DxPNES},ix.ShortRoS));
n.ESSho  =length(intersect(ix.classid{ix.DxES}  ,ix.ShortRoS));
n.dataanddx=length(ix.classid{ix.DxPNES})+length(ix.classid{ix.DxES});
thresh.perc=unique(data.perc);
n.perc.thresh=length(thresh.perc);
data.ROC=zeros(n.perc.thresh,2);
data.AUC=0;
% 1: TPR (sens for PNES)
% 2: FPR (1-spec for ES)
for tnd=1:n.perc.thresh
    data.ROC(tnd,1)=sum(data.perc(ix.classid{ix.DxPNES})>=thresh.perc(tnd))/summary.classes(ix.DxPNES,2);
    data.ROC(tnd,2)=sum(data.perc(ix.classid{ix.DxES})>thresh.perc(tnd))/summary.classes(ix.DxES,2);
    if tnd>1
        data.AUC=data.AUC+(1-data.ROC(tnd,2))*(data.ROC(tnd-1,1)-data.ROC(tnd,1));
    end
end
perc.bacc=(data.ROC(:,1)+(1-data.ROC(:,2)))/2;
[perc.maxbacc,tmp]=max(perc.bacc);
perc.maxbath=thresh.perc(tmp);
perc.maxbasens=data.ROC(tmp,1);
perc.maxbaspec=data.ROC(tmp,2);
perc.acc =(data.ROC(:,1)*summary.classes(ix.DxPNES,2)+(1-data.ROC(:,2))*summary.classes(ix.DxES,2))/(summary.classes(ix.DxPNES,2)+summary.classes(ix.DxES,2));
[perc.maxacc,tmp] =max(perc.acc);
perc.accp=(1-binocdf(perc.maxacc*n.dataanddx,n.dataanddx,max(summary.classes([ix.DxPNES,ix.DxES],2))/n.dataanddx))*2;
perc.maxacth=thresh.perc(tmp);
perc.maxasen=data.ROC(tmp,1);
perc.maxaspe=data.ROC(tmp,2);
perc.AUC    =data.AUC;
figure
pl1=plot(data.ROC(:,2),data.ROC(:,1),'color','black','LineWidth',2);
xlabel('Percent ES above threshold (false positive rate)');
ylabel('Percent PNES above threshold (true positive rate)');
set(gca,'xlim',[0 1],'ylim',[0 1]);
set(gca,'xtick',0:.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'ytick',0:.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
axis square

% Controlling for age/gender
modeldata.X=[data.perc(ix.hasdx) data.demo(ix.hasdx,1) data.demo(ix.hasdx,3)];
% modeldata.X=[data.retro(ix.hasdx,:) data.demo(ix.hasdx,1)];
% modeldata.X=data.retro(ix.hasdx,:);
% modeldata.X=data.demo(ix.hasdx,1);
% modeldata.X=data.perc(ix.hasdx);
% modeldata.X=[data.demo(ix.hasdx,1) data.perc(ix.hasdx) data.demo(ix.hasdx,1).*data.perc(ix.hasdx)];
modeldata.Y=1*(data.class(ix.hasdx)>0);
[b,dev,stats]=glmfit(modeldata.X,modeldata.Y,'binomial');
data.retroyhat=glmval(b,modeldata.X,'logit',stats);
% [b0,dev0,stats0]=glmfit(ones(size(modeldata.Y)),modeldata.Y,'binomial');

%% L1O CV on AUC
data.L1Oyhat=zeros(size(data.retroyhat));
for snd=1:size(data.retroyhat,1)
    iy.train=setdiff(1:size(data.retroyhat,1),snd);
    datatmp.train=modeldata.X(iy.train,:);
    datatmp.class=modeldata.Y(iy.train);
    [bL1O,devL1O,statsL1O]=glmfit(datatmp.train,datatmp.class,'binomial');
    data.L1Oyhat(snd)=glmval(bL1O,modeldata.X(snd,:),'logit',statsL1O);
end
data.L1O.AUC=0;
ix.L1OPNES=find(~modeldata.Y);
ix.L1OES  =find(modeldata.Y);
thresh.L1O=unique(data.L1Oyhat);
n.L1O.thresh=length(thresh.L1O);
data.L1O.ROC=zeros(n.L1O.thresh,2);
for tnd=1:n.L1O.thresh
    data.L1O.ROC(tnd,1)=sum(data.L1Oyhat(ix.L1OPNES)>=thresh.L1O(tnd))/length(ix.L1OPNES);
    data.L1O.ROC(tnd,2)=sum(data.L1Oyhat(ix.L1OES)   >thresh.L1O(tnd))/length(ix.L1OES);
    if tnd>1
        data.L1O.AUC=data.L1O.AUC+(1-data.L1O.ROC(tnd,2))*(data.L1O.ROC(tnd-1,1)-data.L1O.ROC(tnd,1));
    end
end
% SE AUC based on Hanley & McNeil 1982
data.L1O.AUC=1-data.L1O.AUC;
data.L1O.SEQ1=data.L1O.AUC/(2-data.L1O.AUC);
data.L1O.SEQ2=2*data.L1O.AUC^2/(1+data.L1O.AUC);
data.L1O.SEAUC=sqrt((data.L1O.AUC*(1-data.L1O.AUC)+(length(ix.L1OPNES)-1)*(data.L1O.SEQ1-data.L1O.AUC^2)+(length(ix.L1OES)-1)*(data.L1O.SEQ2-data.L1O.AUC^2))/length(ix.L1OPNES)/length(ix.L1OES));

%% Inconclusive Zone
thresh.model=unique(data.retroyhat);
n.perc.model=length(thresh.model);
perc.incgrid=zeros(n.perc.model,n.perc.model,6);
ix.thES=find(modeldata.Y);
ix.thPNES=find(~modeldata.Y);
thdata.Y=(modeldata.Y*2)-1;
% Accuracy
% Sensitivity
% Specificity
% PPV
% NPV
% N-between
for lth=1:(n.perc.model-1)
    for uth=lth:n.perc.model
        temp.pred=(data.retroyhat<=thresh.model(lth))*-1+(data.retroyhat>=thresh.model(uth));
        temp.iscor=1*temp.pred.*thdata.Y;
        twobytwo=zeros(2);
        twobytwo(1,1)=sum(temp.iscor(ix.thES)>0);
        twobytwo(1,2)=sum(temp.iscor(ix.thPNES)<0);
        twobytwo(2,1)=sum(temp.iscor(ix.thES)<0);
        twobytwo(2,2)=sum(temp.iscor(ix.thPNES)>0);
%         twobytwo(1,1)=sum((((data.retroyhat(ix.thPNES)<=thresh.model(lth))*2-1).*thdata.Y(ix.thPNES))>0); % ES correct
%         twobytwo(1,2)=sum((((data.retroyhat(ix.thES  )<=thresh.model(lth))*2-1).*thdata.Y(ix.thES  ))>0); % PNES wrong
%         twobytwo(2,1)=sum((((data.retroyhat(ix.thPNES)>=thresh.model(uth))*2-1).*thdata.Y(ix.thPNES))>0); % ES wrong
%         twobytwo(2,2)=sum((((data.retroyhat(ix.thES  )>=thresh.model(uth))*2-1).*thdata.Y(ix.thES  ))>0); % PNES correct
        perc.incgrid(lth,uth,6)=sum(temp.iscor==0)/n.dataanddx;
        perc.incgrid(lth,uth,1)=(twobytwo(1,1)+twobytwo(2,2))/n.dataanddx;
%         if sum(twobytwo(1,:))
%             if sum(twobytwo(2,:))
%                 perc.incgrid(lth,uth,1)=twobytwo(1,1)/sum(twobytwo(1,:))+twobytwo(2,2)/sum(twobytwo(2,:))-thebetween;
%             else
%                 perc.incgrid(lth,uth,1)=twobytwo(1,1)/sum(twobytwo(1,:))-thebetween;
%             end
%         else
%             perc.incgrid(lth,uth,1)=twobytwo(2,2)/sum(twobytwo(2,:))-thebetween;
%         end
        perc.incgrid(lth,uth,2)=twobytwo(1,1)/length(ix.classid{ix.DxES});
        perc.incgrid(lth,uth,3)=twobytwo(2,2)/length(ix.classid{ix.DxPNES});
        perc.incgrid(lth,uth,4)=twobytwo(1,1)/sum(twobytwo(1,:));
        perc.incgrid(lth,uth,5)=twobytwo(2,2)/sum(twobytwo(2,:));
    end
end
perc.iacc=max(max(perc.incgrid(:,:,1)));
[iy.a iy.b]=find(perc.incgrid(:,:,1)==perc.iacc);
perc.isens=perc.incgrid(iy.a,iy.b,2);
perc.ispec=perc.incgrid(iy.a,iy.b,3);
perc.iPPV=perc.incgrid(iy.a,iy.b,4);
perc.iNPV=perc.incgrid(iy.a,iy.b,5);
perc.ibtwn=perc.incgrid(iy.a,iy.b,6);
perc.ilth=thresh.model(iy.a);
perc.iuth=thresh.model(iy.b);


%% LEOSS Figure
figure;
ssigma=0.02; % Gaussian window

% make exact figure
tmps.percvals=unique(data.perc);
tmps.perchist=zeros(length(tmps.percvals),2);
for ind=1:length(tmps.percvals)
    tmps.perchist(ind,1)=sum(data.perc(ix.classid{ix.DxPNES})==tmps.percvals(ind));
    tmps.perchist(ind,2)=sum(data.perc(ix.classid{ix.DxES})==tmps.percvals(ind));
end
% add smoothing
perc.val=0:1/size(data.retro,2):1;
n.percvals=length(perc.val);
perc.loess=zeros(n.percvals,3); %1: freq, 2:n, 3:for norming
% Gaussian smoothing kernel applied onto tmps.perchist
for ind=1:n.percvals
    for jnd=1:length(tmps.percvals)
        perc.loess(ind,1)=perc.loess(ind,1)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*tmps.perchist(jnd,1);
        perc.loess(ind,2)=perc.loess(ind,2)+normpdf(perc.val(ind)-tmps.percvals(jnd),0,ssigma)*sum(tmps.perchist(jnd,:),2);
        perc.loess(ind,3)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
    end
end
perc.loess=perc.loess./repmat(perc.loess(:,3),[1 3]);
perc.freqbars=zeros(n.percvals,3);
perc.freqbars(:,2)=perc.loess(:,1)./perc.loess(:,2);
for ind=1:n.percvals
    if perc.freqbars(ind,2)==1
        perc.freqbars(ind,[1 3])=abs(perc.freqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),1-1/2/floor(perc.loess(ind,2)))/floor(perc.loess(ind,2)));
    else
        perc.freqbars(ind,[1 3])=abs(perc.freqbars(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(perc.loess(ind,2)),perc.freqbars(ind,2))/floor(perc.loess(ind,2)));
    end
    if perc.loess(ind,2)<2
        perc.freqbars(ind,:)=NaN;
    end
end
hold on
pl4=plot(perc.val,perc.loess(:,1)./perc.loess(:,2),'Color',[0 0 0],'LineWidth',2);
ebs=errbar(perc.val,perc.freqbars(:,2),perc.freqbars(:,1),perc.freqbars(:,3),'LineWidth',3,'Color',[0 0 0]);
hold off
% removeErrorBarEnds(ebs);

ylabel('Percent Patients with PNES vs ES');
xlabel('Percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[0 0.6],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

% >= LOESS Figure
tmpsGT.percvals=unique(data.perc);
tmpsGT.perchist=zeros(n.percvals,2);
perc.freqbarsGT=zeros(n.percvals,3);
for ind=1:n.percvals
    tmpsGT.perchist(ind,1)=sum(data.perc(ix.classid{ix.DxPNES})>=perc.val(ind));
    tmpsGT.perchist(ind,2)=sum(data.perc(ix.classid{ix.DxES})>=perc.val(ind));
    tmps.n=sum(tmpsGT.perchist(ind,:));
    perc.freqbarsGT(ind,2)=tmpsGT.perchist(ind,1)/tmps.n;
    if perc.freqbarsGT(ind,2)==1
        perc.freqbarsGT(ind,[1 3])=abs(perc.freqbarsGT(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(tmps.n),1-1/2/floor(tmps.n))/floor(tmps.n));
    else
        perc.freqbarsGT(ind,[1 3])=abs(perc.freqbarsGT(ind,2)-binoinv([normcdf(-1,0,1) normcdf(1,0,1)],floor(tmps.n),perc.freqbarsGT(ind,2))/floor(tmps.n));
    end
    if tmps.n<=2
        perc.freqbars(ind,:)=NaN;
    end
end

figure;
hold on
pl4=plot(perc.val,perc.freqbarsGT(:,2),'Color',[0 0 0],'LineWidth',2);
ebs=errbar(perc.val,perc.freqbarsGT(:,2),perc.freqbarsGT(:,1),perc.freqbarsGT(:,3),'LineWidth',3,'Color',[0 0 0]);
hold off

ylabel('Percent Patients with PNES vs ES');
xlabel('Greater than or equal to percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[0 0.7],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});


%% Descriptive Trend Figure - 5 classes
figure;
ssigma=0.015; % Gaussian window

% make exact figure
tmps5.percvals=unique(data.perc);
tmps5.perchist=zeros(length(tmps.percvals),n.class);
for ind=1:length(tmps5.percvals)
    for cnd=1:n.class
        tmps5.perchist(ind,cnd)=sum(data.perc(ix.classid{cnd})==tmps5.percvals(ind));
    end
end
% add smoothing
perc.val=0:1/size(data.retro,2):1;
n.percvals=length(perc.val);
perc.r5loess=zeros(n.percvals,3,n.class); %1: freq, 2:n, 3:for norming
% Gaussian smoothing kernel applied onto tmps5.perchist
for ind=1:n.percvals
    for jnd=1:length(tmps5.percvals)
        for cnd=1:n.class
            perc.r5loess(ind,1,cnd)=perc.r5loess(ind,1,cnd)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*tmps5.perchist(jnd,cnd);
        end
        perc.r5loess(ind,2,1)=perc.r5loess(ind,2,1)+normpdf(perc.val(ind)-tmps5.percvals(jnd),0,ssigma)*sum(tmps5.perchist(jnd,:),2);
        perc.r5loess(ind,3,1)=normpdf(perc.val(ind)-perc.val(ind),0,ssigma);
    end
end
perc.r5loess=perc.r5loess./repmat(perc.r5loess(:,3,1),[1 3 n.class]);
perc.r5freqbars=zeros(n.percvals,n.class); % Note that we don't have error bars because that would be too messy
perc.r5freqbars=squeeze(perc.r5loess(:,1,:))./repmat(perc.r5loess(:,2,1),[1 n.class]);
for ind=1:n.percvals
    if perc.r5loess(ind,2,1)<2
        perc.r5freqbars(ind,:)=NaN;
    end
end
ordcl=[2 1 4 3 5];
bar5=bar(perc.val,perc.r5freqbars(:,ordcl),'stacked','BarWidth',1);
% title('Retrospective Data');
set(gca,'fontsize',16);
ylabel('Percent of All Retrospective Patients');
xlabel('Percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[-0.01 0.55],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

set(bar5(1),'FaceColor',Colors5(5,:),'EdgeColor',Colors5(5,:),...
    'DisplayName','PNES');
set(bar5(2),'FaceColor',Colors5(4,:),'EdgeColor',Colors5(4,:),...
    'DisplayName','Mixed');
set(bar5(3),'FaceColor',Colors5(3,:),'EdgeColor',Colors5(3,:),...
    'DisplayName','Inconclusive');
set(bar5(4),'FaceColor',Colors5(2,:),'EdgeColor',Colors5(2,:),...
    'DisplayName','PSLE');
set(bar5(5),'FaceColor',Colors5(1,:),'EdgeColor',Colors5(1,:),...
    'DisplayName','ES');
legend1 = legend(gca,'show');

%>= Figure

tmpsGT5.percvals=unique(data.perc);
tmpsGT5.perchist=zeros(n.percvals,n.class);
perc.freqbarsGT5=zeros(n.percvals,n.class);
for ind=1:n.percvals
    for cnd=1:n.class
        tmpsGT5.perchist(ind,cnd)=sum(data.perc(ix.classid{cnd})>=perc.val(ind));
    end
    tmps.n=sum(tmpsGT5.perchist(ind,:));
    for cnd=1:n.class
        perc.freqbarsGT5(ind,cnd)=tmpsGT5.perchist(ind,cnd)/tmps.n;
    end
end
figure
ordcl=[2 1 4 3 5];
bar5=bar(perc.val,perc.freqbarsGT5(:,ordcl),'stacked','BarWidth',1);
title('Retrospective Data');
set(gca,'fontsize',16);
ylabel('Percent of All Patients');
xlabel('Greater than or equal to percent of RoS Positive');
set(gca,'ylim',[0 1],'ytick',0:0.2:1,'yticklabel',{'0%','20%','40%','60%','80%','100%'});
set(gca,'xlim',[-0.01 0.55],'xtick',0:0.1:1,'xticklabel',{'0%','10%','20%','30%','40%','50%','60%','70%','80%','90%','100%'});

set(bar5(1),... %'FaceColor',[0.70 0.78 1],...
    'DisplayName','PNES');
set(bar5(2),... %'FaceColor',[0.678 0.921 1],...
    'DisplayName','Mixed');
set(bar5(3),... %'FaceColor',[1 0.30 .4],...
    'DisplayName','Inconclusive');
set(bar5(4),... %'FaceColor',[1 0.50 .2],...
    'DisplayName','PSLE');
set(bar5(5),... %'FaceColor',[1 0.50 .2],...
    'DisplayName','ES');
legend1 = legend(gca,'show');


%% By Individual complaint
modeldata.X=data.retro(ix.hasdx,:);
pred=zeros(n.dataanddx,1);
dec =pred;
acc =pred;
for ind=1:n.dataanddx
    iy.train=setdiff(1:n.dataanddx,ind);
    iy.test =ind;
    model=train(modeldata.Y(iy.train),sparse(modeldata.X(iy.train,:)),'-s 0 -q');
    [lab,ac,dc]=predict(modeldata.Y(iy.test),sparse(modeldata.X(iy.test,:)),model,'-q');
    pred(ind)=lab;
    acc (ind)=ac(1);
    dec (ind)=dc;
end
comp.acc=mean(acc)/100;
comp.p  =(1-binocdf(comp.acc*n.dataanddx,n.dataanddx,max(summary.classes(:,2))/n.dataanddx))*2;

summary.indiv=zeros(n.class+1,size(data.retro,2),2);
% Mean
% SE
% p-PNESvsES
for jnd=1:size(data.retro,2)
    if isempty(intersect(ix.shortmissing,jnd+5)) % is the question on the short RoS form
        for ind=1:n.class+1
            summary.indiv(ind,jnd,1)=mean(data.retro(ix.classid{ind},jnd));
            summary.indiv(ind,jnd,2)=std(data.retro(ix.classid{ind},jnd))/sqrt(length(ix.classid{ind}));
        end
        tmpx=[sum(data.retro(ix.classid{ix.DxPNES},jnd)),sum(data.retro(ix.classid{ix.DxES},jnd))];
        tmpn=[length(ix.classid{ix.DxPNES}),length(ix.classid{ix.DxES})];
    else % question is off the short RoS
        fprintf([heads{jnd+5}{1} '\n']);
        for ind=1:n.class+1
            summary.indiv(ind,jnd,1)=mean(data.retro(intersect(ix.classid{ind},ix.ShortRoS),jnd));
            summary.indiv(ind,jnd,2)=std(data.retro(intersect(ix.classid{ind},ix.ShortRoS),jnd))/sqrt(length(intersect(ix.classid{ind},ix.ShortRoS)));
        end
        tmpx=[sum(data.retro(intersect(ix.classid{ix.DxPNES},ix.ShortRoS),jnd)),sum(data.retro(intersect(ix.classid{ix.DxES},ix.ShortRoS),jnd))];
        tmpn=[length(intersect(ix.classid{ix.DxPNES},ix.ShortRoS)),length(intersect(ix.classid{ix.DxES},ix.ShortRoS))];
    end
    if tmpx(1)/tmpn(1)==tmpx(2)/tmpn(2)
        p=1;
    else
        [h,p,stat,df]=prop_test(tmpx,tmpn,true);
    end
    summary.indiv(1,jnd,3)=p;
end
[sortedsig ix.sigsort]=sort(summary.indiv(1,:,3));
minsig=0;
for jnd=1:length(sortedsig)
    sortedsig(jnd)=sortedsig(jnd)*length(sortedsig)/jnd;
    if sortedsig(jnd)<0.05
        if minsig==0
            minsig=jnd;
        else
            if jnd==minsig+1
                minsig=jnd;
%             else
                % there was a non-significant one before this
            end
        end
    end
end
%% Add FDR Correction!
ix.sigfac=ix.sigsort(1:minsig);

% Write Out Table of Significant Factors
fidd=fopen(dirs.sigqs,'w');
fprintf(fidd,'Question,Mixed,Inconclusive,PSLE,PNES,ES,p\n');
ix.classord=[1 4 3 2 5];
for ind=ix.sigfac
    fprintf(fidd,heads{ind+5}{1});
    for jnd=1:n.class
        if max(ix.classord)==n.class
            fprintf(fidd,[',' num2str(round(100*summary.indiv(ix.classord(jnd),ind,1))) ' (' num2str(round(100*summary.indiv(ix.classord(jnd),ind,2))) ')']);
        else
            error 'Fix the class order'
        end
    end
    fprintf(fidd,[',' num2str(summary.indiv(1,ind,3)) '\n']);
end
fclose(fidd);

% display RoS response rates
figure
n.maxdisplay=minsig;
plot2=barh(summary.indiv([ix.DxPNES ix.DxES],ix.sigfac(n.maxdisplay:-1:1),1)','BarWidth',1);
labs=cell(n.maxdisplay,1);
for ind=1:n.maxdisplay
    labs{ind}=heads{5+ix.sigfac(n.maxdisplay+1-ind)}{:};
end
set(gca,'ylim',[0.5 n.maxdisplay+0.5],'ytick',1:n.maxdisplay,'yticklabel',labs);
xlabel('Rate of Positive Response');
set(gca,'xlim',[0 0.8],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});

figure
n.maxdisplay=10;
plot2=barh(summary.indiv([ix.DxPNES ix.DxES],ix.sigfac(n.maxdisplay:-1:1),1)','BarWidth',1);
labs=cell(n.maxdisplay,1);
for ind=1:n.maxdisplay
    labs{ind}=heads{5+ix.sigfac(n.maxdisplay+1-ind)}{:};
end
set(gca,'ylim',[0.5 n.maxdisplay+0.5],'ytick',1:n.maxdisplay,'yticklabel',labs);
xlabel('Rate of Positive Response');
set(gca,'xlim',[0 0.6],'xtick',0:0.2:1,'xticklabel',{'0%','20%','40%','60%','80%','100%'});